@@ -30,7 +30,7 @@ from calibre.utils.filenames import (
     is_case_sensitive, samefile, hardlink_file, ascii_filename,
     WindowsAtomicFolderMove, atomic_rename, remove_dir_if_empty,
     copytree_using_links, copyfile_using_links)
-from calibre.utils.magick.draw import save_cover_data_to
+from calibre.utils.img import save_cover_data_to
 from calibre.utils.formatter_functions import load_user_template_functions
 from calibre.db.tables import (OneToOneTable, ManyToOneTable, ManyToManyTable,
         SizeTable, FormatsTable, AuthorsTable, IdentifiersTable, PathTable,
@@ -47,6 +47,7 @@ Differences in semantics from pysqlite:
 '''
 CUSTOM_DATA_TYPES = frozenset(['rating', 'text', 'comments', 'datetime',
     'int', 'float', 'bool', 'series', 'composite', 'enumeration'])
+WINDOWS_RESERVED_NAMES = frozenset('CON PRN AUX NUL COM1 COM2 COM3 COM4 COM5 COM6 COM7 COM8 COM9 LPT1 LPT2 LPT3 LPT4 LPT5 LPT6 LPT7 LPT8 LPT9'.split())
 
 
 class DynamicFilter(object):  # {{{
@@ -1139,6 +1140,8 @@ class DB(object):
         if not author:
             author = ascii_filename(_('Unknown')).decode(
                     'ascii', 'replace')
+        if author.upper() in WINDOWS_RESERVED_NAMES:
+            author += 'w'
         return '%s/%s%s' % (author, title, book_id)
 
     def construct_file_name(self, book_id, title, author, extlen):
@@ -1373,7 +1376,7 @@ class DB(object):
                     os.remove(path)
         else:
             if no_processing:
-                with open(path, 'wb') as f:
+                with lopen(path, 'wb') as f:
                     f.write(data)
             else:
                 try:
