@@ -7,10 +7,10 @@ __license__   = 'GPL v3'
 __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
-import re, weakref
+import re, weakref, operator
 from functools import partial
 from datetime import timedelta
-from collections import deque
+from collections import deque, OrderedDict
 
 from calibre.constants import preferred_encoding
 from calibre.db.utils import force_to_bool
@@ -85,14 +85,14 @@ def _match(query, value, matchkind, use_primary_find_in_search=True):
 class DateSearch(object):  # {{{
 
     def __init__(self):
-        self.operators = {
-            '=': (1, self.eq),
-            '!=': (2, self.ne),
-            '>': (1, self.gt),
-            '>=': (2, self.ge),
-            '<': (1, self.lt),
-            '<=': (2, self.le),
-        }
+        self.operators = OrderedDict((
+            ('!=', self.ne),
+            ('>=', self.ge),
+            ('<=', self.le),
+            ('=', self.eq),
+            ('>', self.gt),
+            ('<', self.lt),
+        ))
         self.local_today         = {'_today', 'today', icu_lower(_('today'))}
         self.local_yesterday     = {'_yesterday', 'yesterday', icu_lower(_('yesterday'))}
         self.local_thismonth     = {'_thismonth', 'thismonth', icu_lower(_('thismonth'))}
@@ -158,13 +158,12 @@ class DateSearch(object):  # {{{
                     matches |= book_ids
             return matches
 
-        relop = None
-        for k, op in self.operators.iteritems():
+        for k, relop in self.operators.iteritems():
             if query.startswith(k):
-                p, relop = op
-                query = query[p:]
-        if relop is None:
-            relop = self.operators['='][-1]
+                query = query[len(k):]
+                break
+        else:
+            relop = self.operators['=']
 
         if query in self.local_today:
             qd = now()
@@ -206,14 +205,14 @@ class DateSearch(object):  # {{{
 class NumericSearch(object):  # {{{
 
     def __init__(self):
-        self.operators = {
-            '=':(1, lambda r, q: r == q),
-            '>':(1, lambda r, q: r is not None and r > q),
-            '<':(1, lambda r, q: r is not None and r < q),
-            '!=':(2, lambda r, q: r != q),
-            '>=':(2, lambda r, q: r is not None and r >= q),
-            '<=':(2, lambda r, q: r is not None and r <= q)
-        }
+        self.operators = OrderedDict((
+            ('!=', operator.ne),
+            ('>=', operator.ge),
+            ('<=', operator.le),
+            ('=', operator.eq),
+            ('>', operator.gt),
+            ('<', operator.lt),
+        ))
 
     def __call__(self, query, field_iter, location, datatype, candidates, is_many=False):
         matches = set()
@@ -245,18 +244,17 @@ class NumericSearch(object):  # {{{
             else:
                 relop = lambda x,y: x is not None
         else:
-            relop = None
-            for k, op in self.operators.iteritems():
+            for k, relop in self.operators.iteritems():
                 if query.startswith(k):
-                    p, relop = op
-                    query = query[p:]
-            if relop is None:
-                p, relop = self.operators['=']
+                    query = query[len(k):]
+                    break
+            else:
+                relop = self.operators['=']
 
             cast = int
             if dt == 'rating':
                 cast = lambda x: 0 if x is None else int(x)
-                adjust = lambda x: x/2
+                adjust = lambda x: x // 2
             elif dt in ('float', 'composite'):
                 cast = float
 
@@ -684,6 +682,13 @@ class Parser(SearchQueryParser):  # {{{
                         if _match(q, val, matchkind, use_primary_find_in_search=upf):
                             matches |= book_ids
 
+            if location == 'series_sort':
+                book_lang_map = self.dbcache.fields['languages'].book_value_map
+                for val, book_ids in self.dbcache.fields['series'].iter_searchable_values_for_sort(current_candidates, book_lang_map):
+                    if val is not None:
+                        if _match(q, (val,), matchkind, use_primary_find_in_search=upf):
+                            matches |= book_ids
+
         return matches
 
     def get_user_category_matches(self, location, query, candidates):
@@ -715,7 +720,7 @@ class LRUCache(object):  # {{{
 
     'A simple Least-Recently-Used cache'
 
-    def __init__(self, limit=30):
+    def __init__(self, limit=50):
         self.item_map = {}
         self.age_map = deque()
         self.limit = limit
@@ -854,6 +859,14 @@ class Search(object):
         search is on the full library and no virtual field is searched on '''
         if isinstance(search_restriction, bytes):
             search_restriction = search_restriction.decode('utf-8')
+        if isinstance(query, bytes):
+            query = query.decode('utf-8')
+
+        query = query.strip()
+        if book_ids is None and query and not search_restriction:
+            cached = self.cache.get(query)
+            if cached is not None:
+                return cached
 
         restricted_ids = all_book_ids = dbcache._all_book_ids(type=set)
         if search_restriction and search_restriction.strip():
@@ -870,14 +883,11 @@ class Search(object):
         elif book_ids is not None:
             restricted_ids = book_ids
 
-        if isinstance(query, bytes):
-            query = query.decode('utf-8')
-
-        if not query or not query.strip():
+        if not query:
             return restricted_ids
 
         if restricted_ids is all_book_ids:
-            cached = self.cache.get(query.strip())
+            cached = self.cache.get(query)
             if cached is not None:
                 return cached
 
@@ -885,7 +895,7 @@ class Search(object):
         result = sqp.parse(query)
 
         if not sqp.virtual_field_used and sqp.all_book_ids is all_book_ids:
-            self.cache.add(query.strip(), result)
+            self.cache.add(query, result)
 
         return result
 
