@@ -418,6 +418,8 @@ class LegacyTest(BaseTest):
             'migrate_old',  # no longer supported
             'remove_unused_series',  # superseded by clean API
             'move_library_to',  # API changed, no code uses old API
+            # Added compiled_rules() for calibredb add
+            'find_books_in_directory', 'import_book_directory', 'import_book_directory_multiple', 'recursive_import',
 
             # Internal API
             'clean_user_categories',  'cleanup_tags',  'books_list_filter', 'conn', 'connect', 'construct_file_name',
