@@ -566,7 +566,7 @@ def get_device_registry_property(dev_list, p_devinfo, property_type=SPDRP_HARDWA
         if not SetupDiGetDeviceRegistryProperty(dev_list, p_devinfo, property_type, byref(data_type), cast(buf, POINTER(BYTE)), len(buf), byref(required_size)):
             err = get_last_error()
             if err == ERROR_INSUFFICIENT_BUFFER:
-                buf = create_string_buffer(required_size)
+                buf = create_string_buffer(required_size.value)
                 continue
             if err == ERROR_INVALID_DATA:
                 break
@@ -589,7 +589,7 @@ def get_device_interface_detail_data(dev_list, p_interface_data, buf=None):
         if not SetupDiGetDeviceInterfaceDetail(dev_list, p_interface_data, detail, len(buf), byref(required_size), byref(devinfo)):
             err = get_last_error()
             if err == ERROR_INSUFFICIENT_BUFFER:
-                buf = create_string_buffer(required_size + 50)
+                buf = create_string_buffer(required_size.value + 50)
                 detail = cast(buf, PSP_DEVICE_INTERFACE_DETAIL_DATA)
                 detail.contents.cbSize = 8 if is64bit else 6
                 continue
@@ -688,8 +688,7 @@ def get_drive_letters_for_device(usbdev, storage_number_map=None, debug=False):
 
     :param usbdevice: As returned by :function:`scan_usb_devices`
     '''
-    ans = {'pnp_id_map': {}, 'drive_letters':[], 'readonly_drives':set()}
-    sort_map = {}
+    ans = {'pnp_id_map': {}, 'drive_letters':[], 'readonly_drives':set(), 'sort_map':{}}
 
     sn_map = get_storage_number_map(debug=debug) if storage_number_map is None else storage_number_map
     if debug:
@@ -697,7 +696,29 @@ def get_drive_letters_for_device(usbdev, storage_number_map=None, debug=False):
         prints(pformat(sn_map))
     if not sn_map:
         return ans
+    devid, mi = (usbdev.devid or '').rpartition('&')[::2]
+    if mi.startswith('mi_'):
+        if debug:
+            prints('Iterating over all devices of composite device:', devid)
+        dl = ans['drive_letters']
+        for c in iterusbdevices():
+            if c.devid and c.devid.startswith(devid):
+                a = get_drive_letters_for_device_single(c, sn_map, debug=debug)
+                if debug:
+                    prints('Drive letters for:', c.devid, ':', a['drive_letters'])
+                for m in ('pnp_id_map', 'sort_map'):
+                    ans[m].update(a[m])
+                ans['readonly_drives'] |= a['readonly_drives']
+                for x in a['drive_letters']:
+                    if x not in dl:
+                        dl.append(x)
+        ans['drive_letters'].sort(key=ans['sort_map'].get)
+        return ans
+    else:
+        return get_drive_letters_for_device_single(usbdev, sn_map, debug=debug)
 
+def get_drive_letters_for_device_single(usbdev, storage_number_map, debug=False):
+    ans = {'pnp_id_map': {}, 'drive_letters':[], 'readonly_drives':set(), 'sort_map':{}}
     descendants = frozenset(iterdescendants(usbdev.devinst))
     for devinfo, devpath in DeviceSet(GUID_DEVINTERFACE_DISK).interfaces():
         if devinfo.DevInst in descendants:
@@ -715,16 +736,16 @@ def get_drive_letters_for_device(usbdev, storage_number_map=None, debug=False):
             if debug:
                 prints('Storage number for %s: %s' % (devid, storage_number))
             if storage_number:
-                partitions = sn_map.get(storage_number[:2])
+                partitions = storage_number_map.get(storage_number[:2])
                 drive_letters = []
                 for partition_number, dl in partitions or ():
                     drive_letters.append(dl)
-                    sort_map[dl] = storage_number.number, partition_number
+                    ans['sort_map'][dl] = storage_number.number, partition_number
                 if drive_letters:
                     for dl in drive_letters:
                         ans['pnp_id_map'][dl] = devpath
                         ans['drive_letters'].append(dl)
-    ans['drive_letters'].sort(key=sort_map.get)
+    ans['drive_letters'].sort(key=ans['sort_map'].get)
     for dl in ans['drive_letters']:
         try:
             if is_readonly(dl):
@@ -808,18 +829,14 @@ def get_usb_info(usbdev, debug=False):  # {{{
     :param usbdev: A usb device as returned by :function:`scan_usb_devices`
     '''
     ans = {}
-    try:
-        parent = next(iterancestors(usbdev.devinst))
-    except StopIteration:
-        if debug:
-            prints('Cannot get USB info as device has no parent (was probably disconnected)')
-        return ans
-    for devinfo, parent_path in DeviceSet(guid=GUID_DEVINTERFACE_USB_HUB).interfaces():
-        if devinfo.DevInst == parent:
+    hub_map = {devinfo.DevInst:path for devinfo, path in DeviceSet(guid=GUID_DEVINTERFACE_USB_HUB).interfaces()}
+    for parent in iterancestors(usbdev.devinst):
+        parent_path = hub_map.get(parent)
+        if parent_path is not None:
             break
     else:
         if debug:
-            prints('Cannot get USB info as parent of device is not a HUB')
+            prints('Cannot get USB info as parent of device is not a HUB or device has no parent (was probably disconnected)')
         return ans
     for devlist, devinfo in DeviceSet(guid=GUID_DEVINTERFACE_USB_DEVICE).devices():
         if devinfo.DevInst == usbdev.devinst:
@@ -829,7 +846,7 @@ def get_usb_info(usbdev, debug=False):  # {{{
         return ans
     if not device_port:
         if debug:
-            prints('Cannot get usb info as the SPDRP_ADDRESS property is not present int he registry (can happen with broken USB hub drivers)')
+            prints('Cannot get usb info as the SPDRP_ADDRESS property is not present in the registry (can happen with broken USB hub drivers)')
         return ans
     handle = CreateFile(parent_path, GENERIC_READ | GENERIC_WRITE, FILE_SHARE_READ | FILE_SHARE_WRITE, None, OPEN_EXISTING, 0, None)
     try:
