@@ -13,15 +13,8 @@ from lxml import etree
 from calibre import walk
 from calibre.utils.zipfile import ZipFile
 
-def dump(path):
-    dest = os.path.splitext(os.path.basename(path))[0]
-    dest += '-dumped'
-    if os.path.exists(dest):
-        shutil.rmtree(dest)
-    with ZipFile(path) as zf:
-        zf.extractall(dest)
-
-    for f in walk(dest):
+def pretty_all_xml_in_dir(path):
+    for f in walk(path):
         if f.endswith('.xml') or f.endswith('.rels'):
             with open(f, 'r+b') as stream:
                 raw = stream.read()
@@ -31,6 +24,18 @@ def dump(path):
                     stream.truncate()
                     stream.write(etree.tostring(root, pretty_print=True, encoding='utf-8', xml_declaration=True))
 
+def do_dump(path, dest):
+    if os.path.exists(dest):
+        shutil.rmtree(dest)
+    with ZipFile(path) as zf:
+        zf.extractall(dest)
+    pretty_all_xml_in_dir(dest)
+
+def dump(path):
+    dest = os.path.splitext(os.path.basename(path))[0]
+    dest += '-dumped'
+    do_dump(path, dest)
+
     print (path, 'dumped to', dest)
 
 if __name__ == '__main__':
