@@ -13,7 +13,8 @@ from base64 import b64encode
 from lxml import etree
 
 from calibre.utils.date import parse_only_date
-from calibre.utils.magick.draw import save_cover_data_to
+from calibre.utils.img import save_cover_data_to
+from calibre.utils.imghdr import identify
 from calibre import guess_type, guess_all_extensions, prints, force_unicode
 from calibre.ebooks.metadata import MetaInformation, check_isbn
 from calibre.ebooks.chardet import xml_to_unicode
@@ -34,7 +35,7 @@ class Context(object):
 
     def __init__(self, root):
         try:
-            self.fb_ns = root.nsmap[root.prefix]
+            self.fb_ns = root.nsmap[root.prefix] or NAMESPACES['fb2']
         except Exception:
             self.fb_ns = NAMESPACES['fb2']
         self.namespaces = {
@@ -87,7 +88,7 @@ def get_metadata(stream):
     root = _get_fbroot(stream)
     ctx = Context(root)
     book_title = _parse_book_title(root, ctx)
-    authors = _parse_authors(root, ctx)
+    authors = _parse_authors(root, ctx) or [_('Unknown')]
 
     # fallback for book_title
     if book_title:
@@ -210,8 +211,9 @@ def _parse_cover_data(root, imgid, mi, ctx):
         if mime_extensions:
             pic_data = elm_binary[0].text
             if pic_data:
-                mi.cover_data = (mime_extensions[0][1:],
-                        base64_decode(pic_data.strip()))
+                cdata = base64_decode(pic_data.strip())
+                fmt = identify(bytes(cdata))[0]
+                mi.cover_data = (fmt, cdata)
         else:
             prints("WARNING: Unsupported coverpage mime-type '%s' (id=#%s)" % (mimetype, imgid))
 
@@ -227,7 +229,7 @@ def _parse_tags(root, mi, ctx):
 
 def _parse_series(root, mi, ctx):
     # calibri supports only 1 series: use the 1-st one
-    # pick up sequence but only from 1 secrion in prefered order
+    # pick up sequence but only from 1 secrion in preferred order
     # except <src-title-info>
     xp_ti = '//fb:title-info/fb:sequence[1]'
     xp_pi = '//fb:publish-info/fb:sequence[1]'
@@ -236,7 +238,10 @@ def _parse_series(root, mi, ctx):
     if elms_sequence:
         mi.series = elms_sequence[0].get('name', None)
         if mi.series:
-            mi.series_index = elms_sequence[0].get('number', None)
+            try:
+                mi.series_index = float('.'.join(elms_sequence[0].get('number', None).split()[:2]))
+            except Exception:
+                pass
 
 def _parse_isbn(root, mi, ctx):
     # some people try to put several isbn in this field, but it is not allowed.  try to stick to the 1-st one in this case
@@ -338,7 +343,7 @@ def _rnd_pic_file_name(prefix='calibre_cover_', size=32, ext='jpg'):
     return prefix + _rnd_name(size=size) + '.' + ext
 
 def _encode_into_jpeg(data):
-    data = save_cover_data_to(data, 'cover.jpg', return_data=True)
+    data = save_cover_data_to(data)
     return b64encode(data)
 
 def _set_cover(title_info, mi, ctx):
