@@ -222,6 +222,10 @@ def metadata_from_xmp_packet(raw_bytes):
     mi = Metadata(_('Unknown'))
     title = first_alt('//dc:title', root)
     if title:
+        if title.startswith(r'\376\377'):
+            # corrupted XMP packet generated by Nitro PDF. See
+            # https://bugs.launchpad.net/calibre/+bug/1541981
+            raise ValueError('Corrupted XMP metadata packet detected, probably generated by Nitro PDF')
         mi.title = title
     authors = multiple_sequences('//dc:creator', root)
     if authors:
@@ -341,7 +345,7 @@ def consolidate_metadata(info_mi, info):
         # We'll use the xmp tags/authors but fallback to the info ones if the
         # xmp does not have tags/authors. smart_update() should have taken care of
         # the rest
-        info_mi.authors, info_mi.tags = xmp_mi.authors or info_mi.authors, xmp_mi.tags or info_mi.tags
+        info_mi.authors, info_mi.tags = (info_authors if xmp_mi.is_null('authors') else xmp_mi.authors), xmp_mi.tags or info_tags
     return info_mi
 
 def nsmap(*args):
