@@ -721,7 +721,7 @@ class MOBIFile(object):  # {{{
 
         self.index_header = self.index_record = None
         self.indexing_record_nums = set()
-        pir = self.mobi_header.primary_index_record
+        pir = getattr(self.mobi_header, 'primary_index_record', NULL_INDEX)
         if pir != NULL_INDEX:
             self.index_header = IndexHeader(self.records[pir])
             numi = self.index_header.index_count
