@@ -13,7 +13,8 @@ from calibre.ebooks.oeb.base import namespace, barename
 from calibre.ebooks.oeb.base import XHTML, XHTML_NS, urlnormalize
 from calibre.ebooks.oeb.stylizer import Stylizer
 from calibre.ebooks.oeb.transforms.flatcss import KeyMapper
-from calibre.utils.magick.draw import identify_data
+from calibre.ebooks.mobi.utils import convert_color_for_font_tag
+from calibre.utils.imghdr import identify
 
 MBP_NS = 'http://mobipocket.com/ns/mbp'
 def MBP(name):
@@ -125,7 +126,7 @@ class MobiMLizer(object):
             self.mobimlize_elem(body, stylizer, BlockState(nbody),
                                 [FormatState()])
             item.data = nroot
-            #print etree.tostring(nroot)
+            # print etree.tostring(nroot)
 
     def mobimlize_font(self, ptsize):
         return self.fnums[self.fmap[ptsize]]
@@ -280,10 +281,10 @@ class MobiMLizer(object):
                 inline = etree.SubElement(inline, XHTML('b'))
             if istate.bgcolor is not None and istate.bgcolor != 'transparent' :
                 inline = etree.SubElement(inline, XHTML('span'),
-                        bgcolor=istate.bgcolor)
+                        bgcolor=convert_color_for_font_tag(istate.bgcolor))
             if istate.fgcolor != 'black':
                 inline = etree.SubElement(inline, XHTML('font'),
-                        color=unicode(istate.fgcolor))
+                        color=convert_color_for_font_tag(istate.fgcolor))
             if istate.strikethrough:
                 inline = etree.SubElement(inline, XHTML('s'))
             if istate.underline:
@@ -309,8 +310,8 @@ class MobiMLizer(object):
             return
         style = stylizer.style(elem)
         # <mbp:frame-set/> does not exist lalalala
-        if style['display'] in ('none', 'oeb-page-head', 'oeb-page-foot') \
-           or style['visibility'] == 'hidden':
+        if ((style['display'] in ('none', 'oeb-page-head', 'oeb-page-foot') or style['visibility'] == 'hidden') and
+                elem.get('data-calibre-jacket-searchable-tags', None) != '1'):
             id_ = elem.get('id', None)
             if id_:
                 # Keep anchors so people can use display:none
@@ -444,8 +445,8 @@ class MobiMLizer(object):
                             href)
                 else:
                     try:
-                        width, height = identify_data(item.data)[:2]
-                    except:
+                        width, height = identify(item.data)[1:]
+                    except Exception:
                         self.oeb.logger.warn('Invalid image:', href)
                     else:
                         if 'width' not in istate.attrib and 'height' not in \
@@ -555,7 +556,13 @@ class MobiMLizer(object):
             # be added.
             istate.ids and tag in ('a', 'span', 'i', 'b', 'u') and
             len(elem)==0)):
-            self.mobimlize_content(tag, text, bstate, istates)
+                if tag == 'li' and len(istates) > 1 and 'value' in elem.attrib:
+                    try:
+                        value = int(elem.attrib['value'])
+                        istates[-2].list_num = value - 1
+                    except:
+                        pass
+                self.mobimlize_content(tag, text, bstate, istates)
         for child in elem:
             self.mobimlize_elem(child, stylizer, bstate, istates)
             tail = None
