@@ -31,7 +31,7 @@ DEFAULTS = {'azimuth': 'center', 'background-attachment': 'scroll',  # {{{
             'none', 'cue-after': 'none', 'cue-before': 'none', 'cursor':
             'auto', 'direction': 'ltr', 'display': 'inline', 'elevation':
             'level', 'empty-cells': 'show', 'float': 'none', 'font-family':
-            'serif', 'font-size': 'medium', 'font-style': 'normal',
+            'serif', 'font-size': 'medium', 'font-stretch': 'normal', 'font-style': 'normal',
             'font-variant': 'normal', 'font-weight': 'normal', 'height':
             'auto', 'left': 'auto', 'letter-spacing': 'normal', 'line-height':
             'normal', 'list-style-image': 'none', 'list-style-position':
@@ -191,10 +191,17 @@ SHORTHAND_DEFAULTS = {
     'list-style': 'inherit', 'font': 'inherit',
 }
 
+_safe_parser = None
+def safe_parser():
+    global _safe_parser
+    if _safe_parser is None:
+        import logging
+        _safe_parser = CSSParser(loglevel=logging.CRITICAL, validate=False)
+    return _safe_parser
+
 def normalize_filter_css(props):
-    import logging
     ans = set()
-    p = CSSParser(loglevel=logging.CRITICAL, validate=False)
+    p = safe_parser()
     for prop in props:
         n = normalizers.get(prop, None)
         ans.add(prop)
@@ -277,7 +284,7 @@ def condense_sheet(sheet):
         if rule.type == rule.STYLE_RULE:
             condense_rule(rule.style)
 
-def test_normalization():  # {{{
+def test_normalization(return_tests=False):  # {{{
     import unittest
     from cssutils import parseStyle
     from itertools import product
@@ -435,6 +442,8 @@ def test_normalization():  # {{{
             self.assertEqual(style.getProperty('border-left').value, vals.replace('red', 'green'))
 
     tests = unittest.defaultTestLoader.loadTestsFromTestCase(TestNormalization)
+    if return_tests:
+        return tests
     unittest.TextTestRunner(verbosity=4).run(tests)
 # }}}
 
