@@ -9,17 +9,13 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 from cssutils.css import CSSRule
 
 from calibre import force_unicode
-from calibre.constants import plugins
 from calibre.ebooks.oeb.base import OEB_DOCS, OEB_STYLES
 from calibre.ebooks.oeb.polish.check.base import BaseError, WARN
 from calibre.ebooks.oeb.polish.container import OEB_FONTS
 from calibre.ebooks.oeb.polish.fonts import change_font_family_value
-from calibre.ebooks.oeb.polish.utils import guess_type
 from calibre.ebooks.oeb.polish.pretty import pretty_script_or_style
 from calibre.utils.fonts.utils import get_all_font_names
 
-woff = plugins['woff'][0]
-
 class InvalidFont(BaseError):
 
     HELP = _('This font could not be processed. It most likely will'
@@ -74,7 +70,7 @@ class FontAliasing(BaseError):
                     changed = True
             elif mt in OEB_DOCS:
                 for style in container.parsed(name).xpath('//*[local-name()="style"]'):
-                    if style.get('type', 'text/css') == 'text/css':
+                    if style.get('type', 'text/css') == 'text/css' and style.text:
                         sheet = container.parse_css(style.text)
                         if fix_sheet(sheet, self.css_name, self.font_name):
                             style.text = force_unicode(sheet.cssText, 'utf-8')
@@ -95,12 +91,6 @@ def check_fonts(container):
     for name, mt in container.mime_map.iteritems():
         if mt in OEB_FONTS:
             raw = container.raw_data(name)
-            if mt == guess_type('a.woff'):
-                try:
-                    raw = woff.from_woff(raw)
-                except Exception as e:
-                    errors.append(InvalidFont(_('Not a valid WOFF font: %s') % e, name))
-                    continue
             try:
                 name_map = get_all_font_names(raw)
             except Exception as e:
