@@ -6,8 +6,10 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
+from io import BytesIO
+from PIL import Image
+
 from calibre import as_unicode
-from calibre.utils.magick import Image
 from calibre.ebooks.oeb.polish.check.base import BaseError, WARN
 from calibre.ebooks.oeb.polish.check.parsing import EmptyFile
 
@@ -51,14 +53,12 @@ def check_raster_images(name, mt, raw):
     if not raw:
         return [EmptyFile(name)]
     errors = []
-    i = Image()
     try:
-        i.load(raw)
+        i = Image.open(BytesIO(raw))
     except Exception as e:
         errors.append(InvalidImage(as_unicode(e.message), name))
     else:
-        if i.colorspace == 'CMYKColorspace':
+        if i.mode == 'CMYK':
             errors.append(CMYKImage(_('Image is in the CMYK colorspace'), name))
 
     return errors
-
