@@ -16,6 +16,7 @@ from Queue import Queue, Empty
 from calibre import browser
 from calibre.ebooks.oeb.base import OEB_DOCS, OEB_STYLES
 from calibre.ebooks.oeb.polish.container import OEB_FONTS
+from calibre.ebooks.oeb.polish.cover import get_raster_cover_name
 from calibre.ebooks.oeb.polish.utils import guess_type, actual_case_for_name, corrected_case_for_name
 from calibre.ebooks.oeb.polish.check.base import BaseError, WARN, INFO
 
@@ -90,6 +91,10 @@ class LocalLink(BadLink):
              ' book is read on any computer other than the one it was created on.'
              ' Either fix or remove the link.')
 
+class EmptyLink(BadLink):
+
+    HELP = _('This link is empty. This is almost always a mistake. Either fill in the link destination or remove the link tag.')
+
 class UnreferencedResource(BadLink):
 
     HELP = _('This file is included in the book but not referred to by any document in the spine.'
@@ -278,6 +283,8 @@ def check_links(container):
     for name, mt in container.mime_map.iteritems():
         if mt in OEB_DOCS or mt in OEB_STYLES or mt in xml_types:
             for href, lnum, col in container.iterlinks(name):
+                if not href:
+                    a(EmptyLink(_('The link is empty'), name, lnum, col))
                 try:
                     tname = container.href_to_name(href, name)
                 except ValueError:
@@ -327,6 +334,8 @@ def check_links(container):
         elif mt in OEB_DOCS and name not in spine_docs:
             a(UnreferencedDoc(name))
         elif (mt in OEB_FONTS or mt.partition('/')[0] in {'image', 'audio', 'video'}) and name not in spine_resources and name != cover_name:
+            if mt.partition('/')[0] == 'image' and name == get_raster_cover_name(container):
+                continue
             a(UnreferencedResource(name))
         else:
             continue
