@@ -11,7 +11,7 @@ import shutil, re, os
 
 from calibre.ebooks.oeb.base import OPF, OEB_DOCS, XPath, XLINK, xml2text
 from calibre.ebooks.oeb.polish.replace import replace_links, get_recommended_folders
-from calibre.utils.magick.draw import identify, identify_data
+from calibre.utils.imghdr import identify
 
 def set_azw3_cover(container, cover_path, report, options=None):
     existing_image = options is not None and options.get('existing_image', False)
@@ -34,7 +34,7 @@ def set_azw3_cover(container, cover_path, report, options=None):
     container.insert_into_xml(guide, guide.makeelement(
         OPF('reference'), href=href, type='cover'))
     if not existing_image:
-        with open(cover_path, 'rb') as src, container.open(name, 'wb') as dest:
+        with lopen(cover_path, 'rb') as src, container.open(name, 'wb') as dest:
             shutil.copyfileobj(src, dest)
     container.dirty(container.opf_name)
     report(_('Cover updated') if found else _('Cover inserted'))
@@ -113,8 +113,7 @@ COVER_TYPES = {
     'other.ms-coverimage', 'other.ms-thumbimage-standard',
     'other.ms-thumbimage', 'thumbimagestandard', 'cover'}
 
-def find_cover_image(container, strict=False):
-    'Find a raster image marked as a cover in the OPF'
+def find_cover_image2(container, strict=False):
     manifest_id_map = container.manifest_id_map
     mm = container.mime_map
     for meta in container.opf_xpath('//opf:meta[@name="cover" and @content]'):
@@ -146,6 +145,18 @@ def find_cover_image(container, strict=False):
     if largest_cover[0]:
         return largest_cover[0]
 
+def find_cover_image3(container):
+    for name in container.manifest_items_with_property('cover-image'):
+        return name
+
+def find_cover_image(container, strict=False):
+    'Find a raster image marked as a cover in the OPF'
+    ver = container.opf_version_parsed
+    if ver.major < 3:
+        return find_cover_image2(container, strict=strict)
+    else:
+        return find_cover_image3(container)
+
 def get_guides(container):
     guides = container.opf_xpath('//opf:guide')
     if not guides:
@@ -258,7 +269,10 @@ def create_epub_cover(container, cover_path, existing_image, options=None):
     from calibre.ebooks.conversion.config import load_defaults
     from calibre.ebooks.oeb.transforms.cover import CoverManager
 
-    ext = cover_path.rpartition('.')[-1].lower()
+    try:
+        ext = cover_path.rpartition('.')[-1].lower()
+    except Exception:
+        ext = 'jpeg'
     cname, tname = 'cover.' + ext, 'titlepage.xhtml'
     recommended_folders = get_recommended_folders(container, (cname, tname))
 
@@ -273,8 +287,12 @@ def create_epub_cover(container, cover_path, existing_image, options=None):
         raster_cover_item = container.generate_item(cname, id_prefix='cover')
         raster_cover = container.href_to_name(raster_cover_item.get('href'), container.opf_name)
 
-        with open(cover_path, 'rb') as src, container.open(raster_cover, 'wb') as dest:
-            shutil.copyfileobj(src, dest)
+        with container.open(raster_cover, 'wb') as dest:
+            if callable(cover_path):
+                cover_path('write_image', dest)
+            else:
+                with lopen(cover_path, 'rb') as src:
+                    shutil.copyfileobj(src, dest)
     if options is None:
         opts = load_defaults('epub_output')
         keep_aspect = opts.get('preserve_cover_aspect_ratio', False)
@@ -286,19 +304,23 @@ def create_epub_cover(container, cover_path, existing_image, options=None):
         style = 'style="height: 100%%"'
         templ = CoverManager.NONSVG_TEMPLATE.replace('__style__', style)
     else:
-        width, height = 600, 800
-        try:
-            if existing_image:
-                width, height = identify_data(container.raw_data(existing_image, decode=False))[:2]
-            else:
-                width, height = identify(cover_path)[:2]
-        except:
-            container.log.exception("Failed to get width and height of cover")
-        ar = 'xMidYMid meet' if keep_aspect else 'none'
-        templ = CoverManager.SVG_TEMPLATE.replace('__ar__', ar)
-        templ = templ.replace('__viewbox__', '0 0 %d %d'%(width, height))
-        templ = templ.replace('__width__', str(width))
-        templ = templ.replace('__height__', str(height))
+        if callable(cover_path):
+            templ = (options or {}).get('template', CoverManager.SVG_TEMPLATE)
+        else:
+            width, height = 600, 800
+            try:
+                if existing_image:
+                    width, height = identify(container.raw_data(existing_image, decode=False))[1:]
+                else:
+                    with lopen(cover_path, 'rb') as csrc:
+                        width, height = identify(csrc)[1:]
+            except:
+                container.log.exception("Failed to get width and height of cover")
+            ar = 'xMidYMid meet' if keep_aspect else 'none'
+            templ = CoverManager.SVG_TEMPLATE.replace('__ar__', ar)
+            templ = templ.replace('__viewbox__', '0 0 %d %d'%(width, height))
+            templ = templ.replace('__width__', str(width))
+            templ = templ.replace('__height__', str(height))
     folder = recommended_folders[tname]
     if folder:
         tname = folder + '/' + tname
@@ -412,5 +434,6 @@ def set_epub_cover(container, cover_path, report, options=None):
         if s is not None and s != d}
     if link_sub:
         replace_links(container, link_sub, frag_map=lambda x, y:None)
+    return raster_cover, titlepage
 
 
