@@ -13,6 +13,7 @@ from lxml import etree
 from calibre import prepare_string_for_xml, CurrentDir
 from calibre.ptempfile import TemporaryDirectory
 from calibre.ebooks.oeb.base import serialize
+from calibre.ebooks.metadata import authors_to_string
 from calibre.ebooks.metadata.opf2 import metadata_to_opf
 from calibre.ebooks.oeb.polish.parsing import parse
 from calibre.ebooks.oeb.polish.container import OPF_NAMESPACES, opf_to_azw3, Container
@@ -23,6 +24,8 @@ from calibre.utils.localization import lang_as_iso639_1
 from calibre.utils.logging import DevNull
 from calibre.utils.zipfile import ZipFile, ZIP_STORED
 
+valid_empty_formats = {'epub', 'txt', 'docx', 'azw3'}
+
 def create_toc(mi, opf, html_name, lang):
     uuid = ''
     for u in opf.xpath('//*[@id="uuid_id"]'):
@@ -33,6 +36,24 @@ def create_toc(mi, opf, html_name, lang):
 
 def create_book(mi, path, fmt='epub', opf_name='metadata.opf', html_name='start.xhtml', toc_name='toc.ncx'):
     ''' Create an empty book in the specified format at the specified location. '''
+    if fmt not in valid_empty_formats:
+        raise ValueError('Cannot create empty book in the %s format' % fmt)
+    if fmt == 'txt':
+        with open(path, 'wb') as f:
+            if not mi.is_null('title'):
+                f.write(mi.title)
+        return
+    if fmt == 'docx':
+        from calibre.ebooks.conversion.plumber import Plumber
+        from calibre.ebooks.docx.writer.container import DOCX
+        from calibre.utils.logging import default_log
+        p = Plumber('a.docx', 'b.docx', default_log)
+        p.setup_options()
+        # Use the word default of one inch page margins
+        for x in 'left right top bottom'.split():
+            setattr(p.opts, 'margin_' + x, 72)
+        DOCX(p.opts, default_log).write(path, mi, create_empty_document=True)
+        return
     path = os.path.abspath(path)
     lang = 'und'
     opf = metadata_to_opf(mi, as_string=False)
@@ -63,19 +84,13 @@ def create_book(mi, path, fmt='epub', opf_name='metadata.opf', html_name='start.
    </rootfiles>
 </container>
     '''.format(prepare_string_for_xml(opf_name, True)).encode('utf-8')
-    HTML = '''\
-<?xml version='1.0' encoding='utf-8'?>
-<html lang="{1}" xmlns="http://www.w3.org/1999/xhtml">
-
-    <head>
-        <title>{0}</title>
-    </head>
-
-    <body>
-        <h1>{0}</h1>
-    </body>
-</html>
-    '''.format(prepare_string_for_xml(mi.title), lang).encode('utf-8')
+    HTML = P('templates/new_book.html', data=True).decode('utf-8').replace(
+        '_LANGUAGE_', prepare_string_for_xml(lang, True)
+    ).replace(
+        '_TITLE_', prepare_string_for_xml(mi.title)
+    ).replace(
+        '_AUTHORS_', prepare_string_for_xml(authors_to_string(mi.authors))
+    ).encode('utf-8')
     h = parse(HTML)
     pretty_html_tree(None, h)
     HTML = serialize(h, 'text/html')
@@ -103,7 +118,7 @@ if __name__ == '__main__':
     mi = Metadata('Test book', authors=('Kovid Goyal',))
     path = sys.argv[-1]
     ext = path.rpartition('.')[-1].lower()
-    if ext not in ('epub', 'azw3'):
+    if ext not in valid_empty_formats:
         print ('Unsupported format:', ext)
         raise SystemExit(1)
     create_book(mi, path, fmt=ext)
