@@ -270,7 +270,7 @@ class PDFStream(object):
         self.compress = compress
         self.write_line(PDFVER)
         self.write_line(b'%íì¦"')
-        creator = ('%s %s [http://calibre-ebook.com]'%(__appname__,
+        creator = ('%s %s [https://calibre-ebook.com]'%(__appname__,
                                     __version__))
         self.write_line('%% Created by %s'%creator)
         self.objects = IndirectObjects()
@@ -377,9 +377,10 @@ class PDFStream(object):
             self.fill_opacities[opacity] = self.objects.add(op)
         self.current_page.set_opacity(self.fill_opacities[opacity])
 
-    def end_page(self):
-        pageref = self.current_page.end(self.objects, self.stream)
-        self.page_tree.obj.add_page(pageref)
+    def end_page(self, drop_page=False):
+        if not drop_page:
+            pageref = self.current_page.end(self.objects, self.stream)
+            self.page_tree.obj.add_page(pageref)
         self.current_page = Page(self.page_tree, compress=self.compress)
 
     def draw_glyph_run(self, transform, size, font_metrics, glyphs):
