@@ -13,8 +13,7 @@ class CheckEncoding:
             try:
                 char.decode(encoding)
             except UnicodeError, msg:
-                sys.stderr.write('line: %s char: %s\n' %  (line_num, char_position))
-                sys.stderr.write(str(msg) + '\n')
+                sys.stderr.write('line: %s char: %s\n%s\n' %  (line_num, char_position, str(msg)))
 
     def check_encoding(self, path, encoding='us-ascii', verbose=True):
         line_num = 0
