@@ -1,6 +1,7 @@
-import sys, os, tempfile
+import sys, os
 
 from calibre.ebooks.rtf2xml import copy
+from calibre.ptempfile import better_mktemp
 
 """
 States.
@@ -37,7 +38,7 @@ class Inline:
         self.__bug_handler = bug_handler
         self.__copy = copy
         self.__run_level = run_level
-        self.__write_to = tempfile.mktemp()
+        self.__write_to = better_mktemp()
 
     def __initiate_values(self):
         """
@@ -418,4 +419,4 @@ class Inline:
         if self.__copy:
             copy_obj.copy_file(self.__write_to, "inline.data")
         copy_obj.rename(self.__write_to, self.__file)
-        os.remove(self.__write_to)
\ No newline at end of file
+        os.remove(self.__write_to)
