@@ -8,10 +8,11 @@ __docformat__ = 'restructuredtext en'
 from functools import partial
 from zipfile import ZipFile
 
-from PyQt4.Qt import (QToolButton, QAction, QIcon, QObject, QMenu,
+from PyQt5.Qt import (QToolButton, QAction, QIcon, QObject, QMenu,
         QKeySequence)
 
 from calibre import prints
+from calibre.constants import isosx
 from calibre.gui2 import Dispatcher
 from calibre.gui2.keyboard import NameConflict
 
@@ -191,7 +192,11 @@ class InterfaceAction(QObject):
                         pass
                     shortcut_action.setShortcuts([QKeySequence(key,
                         QKeySequence.PortableText) for key in keys])
-
+                else:
+                    if isosx:
+                        # In Qt 5 keyboard shortcuts dont work unless the
+                        # action is explicitly added to the main window
+                        self.gui.addAction(shortcut_action)
 
         if attr is not None:
             setattr(self, attr, action)
@@ -253,6 +258,10 @@ class InterfaceAction(QObject):
             self.gui.keyboard.register_shortcut(unique_name,
                 shortcut_name, default_keys=keys,
                 action=ac, description=description, group=self.action_spec[0])
+            # In Qt 5 keyboard shortcuts dont work unless the
+            # action is explicitly added to the main window and on OSX and
+            # Unity since the menu might be exported, the shortcuts wont work
+            self.gui.addAction(ac)
         if triggered is not None:
             ac.triggered.connect(triggered)
         return ac
