@@ -11,6 +11,7 @@ from collections import Counter
 
 from PyQt5.Qt import QObject, QTimer, QModelIndex
 
+from calibre.constants import isosx
 from calibre.gui2 import error_dialog, question_dialog
 from calibre.gui2.dialogs.delete_matching_from_device import DeleteMatchingFromDeviceDialog
 from calibre.gui2.dialogs.confirm_delete import confirm
@@ -84,7 +85,7 @@ class MultiDeleter(QObject):  # {{{
 class DeleteAction(InterfaceAction):
 
     name = 'Remove Books'
-    action_spec = (_('Remove books'), 'trash.png', _('Delete books'), 'Del')
+    action_spec = (_('Remove books'), 'trash.png', _('Delete books'), 'Backspace' if isosx else 'Del')
     action_type = 'current'
     action_add_menu = True
     action_menu_clone_qaction = _('Remove selected books')
