@@ -9,11 +9,13 @@ __docformat__ = 'restructuredtext en'
 
 import os, tempfile, shutil, time
 from threading import Thread, Event
+from future_builtins import map
 
 from PyQt5.Qt import (QFileSystemWatcher, QObject, Qt, pyqtSignal, QTimer)
 
 from calibre import prints
 from calibre.ptempfile import PersistentTemporaryDirectory
+from calibre.db.adding import filter_filename, compile_rule
 from calibre.ebooks import BOOK_EXTENSIONS
 from calibre.gui2 import gprefs
 from calibre.gui2.dialogs.duplicates import DuplicatesQuestion
@@ -47,6 +49,22 @@ class Worker(Thread):
         self.path, self.callback = path, callback
         self.staging = set()
         self.allowed = allowed_formats()
+        self.read_rules()
+
+    def read_rules(self):
+        try:
+            self.compiled_rules = tuple(map(compile_rule, gprefs.get('add_filter_rules', ())))
+        except Exception:
+            self.compiled_rules = ()
+            import traceback
+            traceback.print_exc()
+
+    def is_filename_allowed(self, filename):
+        allowed = filter_filename(self.compiled_rules, filename)
+        if allowed is None:
+            ext = os.path.splitext(filename)[1][1:].lower()
+            allowed = ext in self.allowed
+        return allowed
 
     def run(self):
         self.tdir = PersistentTemporaryDirectory('_auto_adder')
@@ -76,13 +94,19 @@ class Worker(Thread):
                     # Must have read and write permissions
                     os.access(os.path.join(self.path, x), os.R_OK|os.W_OK) and
                     # Must be a known ebook file type
-                    os.path.splitext(x)[1][1:].lower() in self.allowed
+                    self.is_filename_allowed(x)
                 ]
-        data = {}
+        data = []
         # Give any in progress copies time to complete
         time.sleep(2)
 
-        for fname in files:
+        def safe_mtime(x):
+            try:
+                return os.path.getmtime(os.path.join(self.path, x))
+            except EnvironmentError:
+                return time.time()
+
+        for fname in sorted(files, key=safe_mtime):
             f = os.path.join(self.path, fname)
 
             # Try opening the file for reading, if the OS prevents us, then at
@@ -123,7 +147,7 @@ class Worker(Thread):
                 with open(opfpath, 'wb') as f:
                     f.write(metadata_to_opf(mi))
             self.staging.add(fname)
-            data[fname] = tdir
+            data.append((fname, tdir))
         if data:
             self.callback(data)
 
@@ -149,6 +173,10 @@ class AutoAdder(QObject):
             prints(path,
                 'is not a valid directory to watch for new ebooks, ignoring')
 
+    def read_rules(self):
+        if hasattr(self, 'worker'):
+            self.worker.read_rules()
+
     def initialize(self):
         try:
             if os.listdir(self.worker.path):
@@ -186,7 +214,7 @@ class AutoAdder(QObject):
         duplicates = []
         added_ids = set()
 
-        for fname, tdir in data.iteritems():
+        for fname, tdir in data:
             paths = [os.path.join(self.worker.path, fname)]
             sz = os.path.join(tdir, 'size.txt')
             try:
@@ -255,7 +283,7 @@ class AutoAdder(QObject):
                 num = len(ids)
                 count += num
 
-        for tdir in data.itervalues():
+        for fname, tdir in data:
             try:
                 shutil.rmtree(tdir)
             except:
