@@ -10,12 +10,13 @@ __docformat__ = 'restructuredtext en'
 import weakref
 
 import sip
-from PyQt4.Qt import (QLineEdit, QAbstractListModel, Qt, pyqtSignal, QObject,
-        QApplication, QListView, QPoint, QModelIndex, QFont, QFontInfo)
+from PyQt5.Qt import (
+    QLineEdit, QAbstractListModel, Qt, pyqtSignal, QObject, QKeySequence,
+    QApplication, QListView, QPoint, QModelIndex, QFont, QFontInfo,
+    QStyleOptionComboBox, QStyle, QComboBox, QTimer)
 
 from calibre.constants import isosx, get_osx_version
 from calibre.utils.icu import sort_key, primary_startswith, primary_contains
-from calibre.gui2 import NONE
 from calibre.gui2.widgets import EnComboBox, LineEditECM
 from calibre.utils.config import tweaks
 
@@ -34,9 +35,10 @@ class CompleteModel(QAbstractListModel):  # {{{
         items = [unicode(x.strip()) for x in items]
         items = [x for x in items if x]
         items = tuple(sorted(items, key=self.sort_func))
+        self.beginResetModel()
         self.all_items = self.current_items = items
         self.current_prefix = ''
-        self.reset()
+        self.endResetModel()
 
     def set_completion_prefix(self, prefix):
         old_prefix = self.current_prefix
@@ -44,14 +46,16 @@ class CompleteModel(QAbstractListModel):  # {{{
         if prefix == old_prefix:
             return
         if not prefix:
+            self.beginResetModel()
             self.current_items = self.all_items
-            self.reset()
+            self.endResetModel()
             return
         subset = prefix.startswith(old_prefix)
         universe = self.current_items if subset else self.all_items
         func = primary_startswith if tweaks['completion_mode'] == 'prefix' else containsq
+        self.beginResetModel()
         self.current_items = tuple(x for x in universe if func(x, prefix))
-        self.reset()
+        self.endResetModel()
 
     def rowCount(self, *args):
         return len(self.current_items)
@@ -62,7 +66,6 @@ class CompleteModel(QAbstractListModel):  # {{{
                 return self.current_items[index.row()]
             except IndexError:
                 pass
-        return NONE
 
     def index_for_prefix(self, prefix):
         for i, item in enumerate(self.current_items):
@@ -190,6 +193,12 @@ class Completer(QListView):  # {{{
                 self.setFont(f)
             p.show()
 
+    def debug_event(self, ev):
+        from calibre.gui2 import event_type_name
+        print ('Event:', event_type_name(ev))
+        if ev.type() in (ev.KeyPress, ev.ShortcutOverride, ev.KeyRelease):
+            print ('\tkey:', QKeySequence(ev.key()).toString())
+
     def eventFilter(self, obj, e):
         'Redirect key presses from the popup to the widget'
         widget = self.completer_widget()
@@ -199,6 +208,8 @@ class Completer(QListView):  # {{{
         if obj is not self:
             return QObject.eventFilter(self, obj, e)
 
+        # self.debug_event(e)
+
         if etype == e.KeyPress:
             key = e.key()
             if key == Qt.Key_Escape:
@@ -243,11 +254,27 @@ class Completer(QListView):  # {{{
                 self.hide()
             if e.isAccepted():
                 return True
-        elif etype == e.MouseButtonPress:
-            if not self.underMouse():
-                self.hide()
-                e.accept()
-                return True
+        elif isosx and etype == e.InputMethodQuery and e.queries() == (Qt.ImHints | Qt.ImEnabled) and self.isVisible():
+            # In Qt 5 the Esc key causes this event and the line edit does not
+            # handle it, which causes the parent dialog to be closed
+            # See https://bugreports.qt-project.org/browse/QTBUG-41806
+            e.accept()
+            return True
+        elif etype == e.MouseButtonPress and not self.rect().contains(self.mapFromGlobal(e.globalPos())):
+            # A click outside the popup, close it
+            if isinstance(widget, QComboBox):
+                # This workaround is needed to ensure clicking on the drop down
+                # arrow of the combobox closes the popup
+                opt = QStyleOptionComboBox()
+                widget.initStyleOption(opt)
+                sc = widget.style().hitTestComplexControl(QStyle.CC_ComboBox, opt, widget.mapFromGlobal(e.globalPos()), widget)
+                if sc == QStyle.SC_ComboBoxArrow:
+                    QTimer.singleShot(0, self.hide)
+                    e.accept()
+                    return True
+            self.hide()
+            e.accept()
+            return True
         elif etype in (e.InputMethod, e.ShortcutOverride):
             QApplication.sendEvent(widget, e)
         return False
@@ -263,6 +290,7 @@ class LineEdit(QLineEdit, LineEditECM):
     A call to self.set_separator(None) will allow this widget to be used
     to complete non multiple fields as well.
     '''
+    item_selected = pyqtSignal(object)
 
     def __init__(self, parent=None, completer_widget=None, sort_func=sort_key):
         QLineEdit.__init__(self, parent)
@@ -312,6 +340,13 @@ class LineEdit(QLineEdit, LineEditECM):
         return property(fget=fget, fset=fset)
     # }}}
 
+    def event(self, ev):
+        # See https://bugreports.qt.io/browse/QTBUG-46911
+        if ev.type() == ev.ShortcutOverride and (
+                ev.key() in (Qt.Key_Left, Qt.Key_Right) and (ev.modifiers() & ~Qt.KeypadModifier) == Qt.ControlModifier):
+            ev.accept()
+        return QLineEdit.event(self, ev)
+
     def complete(self, show_all=False, select_first=True):
         orig = None
         if show_all:
@@ -380,12 +415,16 @@ class LineEdit(QLineEdit, LineEditECM):
         before_text, after_text = self.get_completed_text(unicode(text))
         self.setText(before_text + after_text)
         self.setCursorPosition(len(before_text))
+        self.item_selected.emit(text)
 
 class EditWithComplete(EnComboBox):
 
+    item_selected = pyqtSignal(object)
+
     def __init__(self, *args, **kwargs):
         EnComboBox.__init__(self, *args)
         self.setLineEdit(LineEdit(self, completer_widget=self, sort_func=kwargs.get('sort_func', sort_key)))
+        self.lineEdit().item_selected.connect(self.item_selected)
         self.setCompleter(None)
         self.eat_focus_out = True
         self.installEventFilter(self)
@@ -468,7 +507,7 @@ class EditWithComplete(EnComboBox):
         return EnComboBox.eventFilter(self, obj, e)
 
 if __name__ == '__main__':
-    from PyQt4.Qt import QDialog, QVBoxLayout
+    from PyQt5.Qt import QDialog, QVBoxLayout
     app = QApplication([])
     d = QDialog()
     d.setLayout(QVBoxLayout())
