@@ -134,7 +134,7 @@ class Rating(Int):
         w = self.widgets[1]
         w.setRange(0, 5)
         w.setSuffix(' '+_('star(s)'))
-        w.setSpecialValueText(_('Unrated'))
+        w.setSpecialValueText(_('Not rated'))
 
     def setter(self, val):
         if val is None:
@@ -233,7 +233,7 @@ class Comments(Base):
         self._box = QGroupBox(parent)
         self._box.setTitle('&'+self.col_metadata['name'])
         self._layout = QVBoxLayout()
-        self._tb = CommentsEditor(self._box)
+        self._tb = CommentsEditor(self._box, toolbar_prefs_name=u'metadata-comments-editor-widget-hidden-toolbars')
         self._tb.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Minimum)
         # self._tb.setTabChangesFocus(True)
         self._layout.addWidget(self._tb)
@@ -349,7 +349,7 @@ class Text(Base):
         if self.col_metadata['is_multiple']:
             self.setter(val)
         else:
-            self.widgets[1].show_initial_value(val)
+            self.widgets[1].setText(val)
         self.initial_val = self.current_val
 
     def setter(self, val):
@@ -428,7 +428,7 @@ class Series(Base):
         val = self.normalize_db_val(val)
         self.name_widget.blockSignals(True)
         self.name_widget.update_items_cache(values)
-        self.name_widget.show_initial_value(val)
+        self.name_widget.setText(val)
         self.name_widget.blockSignals(False)
         self.initial_val, self.initial_index = self.current_val
 
@@ -794,7 +794,7 @@ class BulkRating(BulkBase):
         self.make_widgets(parent, QSpinBox)
         self.main_widget.setRange(0, 5)
         self.main_widget.setSuffix(' '+_('star(s)'))
-        self.main_widget.setSpecialValueText(_('Unrated'))
+        self.main_widget.setSpecialValueText(_('Not rated'))
         self.main_widget.setSingleStep(1)
 
     def setter(self, val):
@@ -1048,7 +1048,7 @@ class BulkText(BulkBase):
             self.initial_val = val = self.normalize_db_val(val)
             self.ignore_change_signals = True
             self.main_widget.blockSignals(True)
-            self.main_widget.show_initial_value(val)
+            self.main_widget.setText(val)
             self.main_widget.blockSignals(False)
             self.ignore_change_signals = False
 
