@@ -3,7 +3,7 @@ __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
 
-from PyQt4.QtGui import QDialog
+from PyQt5.Qt import QDialog
 
 from calibre.gui2.dialogs.saved_search_editor_ui import Ui_SavedSearchEditor
 from calibre.utils.icu import sort_key
@@ -19,9 +19,9 @@ class SavedSearchEditor(QDialog, Ui_SavedSearchEditor):
         Ui_SavedSearchEditor.__init__(self)
         self.setupUi(self)
 
-        self.add_search_button.clicked[()].connect(self.add_search)
+        self.add_search_button.clicked.connect(self.add_search)
         self.search_name_box.currentIndexChanged[(int)].connect(self.current_index_changed)
-        self.delete_search_button.clicked[()].connect(self.del_search)
+        self.delete_search_button.clicked.connect(self.del_search)
         self.rename_button.clicked.connect(self.rename_search)
 
         self.current_search_name = None
@@ -35,12 +35,22 @@ class SavedSearchEditor(QDialog, Ui_SavedSearchEditor):
             self.select_search(initial_search)
 
     def populate_search_list(self):
+        self.search_name_box.blockSignals(True)
         self.search_name_box.clear()
+        self.search_name_box.addItem('')
         for name in sorted(self.searches.keys(), key=sort_key):
             self.search_name_box.addItem(name)
+        self.search_names = set([icu_lower(n) for n in self.searches.keys()])
+        self.search_name_box.blockSignals(False)
+
+    def sanitize_name(self):
+        n = unicode(self.input_box.text()).strip().replace('\\', '')
+        self.input_box.setText(n)
+        return n
 
     def add_search(self):
-        search_name = unicode(self.input_box.text()).strip()
+        self.save_current_search()
+        search_name = self.sanitize_name()
         if search_name == '':
             return False
         if icu_lower(search_name) in self.search_names:
@@ -67,7 +77,8 @@ class SavedSearchEditor(QDialog, Ui_SavedSearchEditor):
             self.search_name_box.removeItem(self.search_name_box.currentIndex())
 
     def rename_search(self):
-        new_search_name = unicode(self.input_box.text()).strip()
+        self.save_current_search()
+        new_search_name = self.sanitize_name()
         if new_search_name == '':
             return False
         if icu_lower(new_search_name) in self.search_names:
@@ -78,6 +89,7 @@ class SavedSearchEditor(QDialog, Ui_SavedSearchEditor):
         if self.current_search_name in self.searches:
             self.searches[new_search_name] = self.searches[self.current_search_name]
             del self.searches[self.current_search_name]
+            self.current_search_name = None
             self.populate_search_list()
             self.select_search(new_search_name)
         return True
@@ -96,11 +108,14 @@ class SavedSearchEditor(QDialog, Ui_SavedSearchEditor):
             self.current_search_name  = None
             self.search_text.setPlainText('')
 
+    def save_current_search(self):
+        if self.current_search_name:
+            self.searches[self.current_search_name] = unicode(self.search_text.toPlainText())
+
     def accept(self):
         from calibre.gui2.ui import get_gui
         db = get_gui().current_db
-        if self.current_search_name:
-            self.searches[self.current_search_name] = unicode(self.search_text.toPlainText())
+        self.save_current_search()
         ss = {name:self.searches[name] for name in self.searches}
         db.saved_search_set_all(ss)
         QDialog.accept(self)
