@@ -4,14 +4,16 @@ __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 import re, copy
 from datetime import date
 
-from PyQt4.Qt import QDialog, QDialogButtonBox
+from PyQt5.Qt import QDialog, QDialogButtonBox
 
+from calibre import strftime
 from calibre.gui2.dialogs.search_ui import Ui_Dialog
 from calibre.library.caches import CONTAINS_MATCH, EQUALS_MATCH
 from calibre.gui2 import gprefs
 from calibre.utils.icu import sort_key
 from calibre.utils.config import tweaks
 from calibre.utils.date import now
+from calibre.utils.localization import localize_user_manual_link
 
 box_values = {}
 last_matchkind = CONTAINS_MATCH
@@ -27,14 +29,15 @@ def init_dateop(cb):
         cb.addItem(desc, op)
 
 def current_dateop(cb):
-    return unicode(cb.itemData(cb.currentIndex()).toString())
+    return unicode(cb.itemData(cb.currentIndex()) or '')
 
 class SearchDialog(QDialog, Ui_Dialog):
 
     def __init__(self, parent, db):
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        for val, text in [(0, '')] + [(i, date(2010, i, 1).strftime('%B')) for i in xrange(1, 13)]:
+        self.um_label.setText(self.um_label.text() % localize_user_manual_link('https://manual.calibre-ebook.com/gui.html#the-search-interface'))
+        for val, text in [(0, '')] + [(i, strftime('%B', date(2010, i, 1).timetuple())) for i in xrange(1, 13)]:
             self.date_month.addItem(text, val)
         for val, text in [('today', _('Today')), ('yesterday', _('Yesterday')), ('thismonth', _('This month'))]:
             self.date_human.addItem(text, val)
@@ -48,6 +51,7 @@ class SearchDialog(QDialog, Ui_Dialog):
         self.date_month.currentIndexChanged.connect(lambda : self.sel_date.setChecked(True))
         self.date_day.valueChanged.connect(lambda : self.sel_date.setChecked(True))
         self.date_daysago.valueChanged.connect(lambda : self.sel_daysago.setChecked(True))
+        self.date_ago_type.addItems([_('days'), _('weeks'), _('months'), _('years')])
         self.date_human.currentIndexChanged.connect(lambda : self.sel_human.setChecked(True))
         init_dateop(self.dateop_date)
         self.sel_date.setChecked(True)
@@ -91,6 +95,7 @@ class SearchDialog(QDialog, Ui_Dialog):
 
         self.tabWidget.currentChanged[int].connect(self.tab_changed)
         self.tab_changed(current_tab)
+        self.resize(self.sizeHint())
 
     def save_state(self):
         gprefs['advanced search dialog current tab'] = \
@@ -127,12 +132,12 @@ class SearchDialog(QDialog, Ui_Dialog):
         return (self.adv_search_string, self.box_search_string, self.date_search_string)[i]()
 
     def date_search_string(self):
-        field = unicode(self.date_field.itemData(self.date_field.currentIndex()).toString())
+        field = unicode(self.date_field.itemData(self.date_field.currentIndex()) or '')
         op = current_dateop(self.dateop_date)
         prefix = '%s:%s' % (field, op)
         if self.sel_date.isChecked():
             ans = '%s%s' % (prefix, self.date_year.value())
-            m = self.date_month.itemData(self.date_month.currentIndex()).toPyObject()
+            m = self.date_month.itemData(self.date_month.currentIndex())
             if m > 0:
                 ans += '-%s' % m
                 d = self.date_day.value()
@@ -140,8 +145,10 @@ class SearchDialog(QDialog, Ui_Dialog):
                     ans += '-%s' % d
             return ans
         if self.sel_daysago.isChecked():
-            return '%s%sdaysago' % (prefix, self.date_daysago.value())
-        return '%s%s' % (prefix, unicode(self.date_human.itemData(self.date_human.currentIndex()).toString()))
+            val = self.date_daysago.value()
+            val *= {0:1, 1:7, 2:30, 3:365}[self.date_ago_type.currentIndex()]
+            return '%s%sdaysago' % (prefix, val)
+        return '%s%s' % (prefix, unicode(self.date_human.itemData(self.date_human.currentIndex()) or ''))
 
     def adv_search_string(self):
         mk = self.matchkind.currentIndex()
