@@ -13,7 +13,7 @@ from threading import Thread
 from itertools import repeat
 from collections import defaultdict
 
-from PyQt4.Qt import (
+from PyQt5.Qt import (
     Qt, QDialog, QGridLayout, QIcon, QListWidget, QDialogButtonBox,
     QListWidgetItem, QLabel, QLineEdit, QPushButton)
 
@@ -63,7 +63,7 @@ class Sendmail(object):
         opts = email_config().parse()
         rh = opts.relay_host
         if rh and (
-            'gmail.com' in rh or 'live.com' in rh):
+            'gmail.com' in rh or 'live.com' in rh or 'gmx.com' in rh):
             self.rate_limit = tweaks['public_smtp_relay_delay']
 
     def __call__(self, attachment, aname, to, subject, text, log=None,
@@ -115,13 +115,19 @@ class Sendmail(object):
             eto = []
             for x in to.split(','):
                 eto.append(extract_email_address(x.strip()))
+            def safe_debug(*args, **kwargs):
+                try:
+                    return log.debug(*args, **kwargs)
+                except Exception:
+                    pass
+
             sendmail(msg, efrom, eto, localhost=None,
                         verbose=1,
                         relay=opts.relay_host,
                         username=opts.relay_username,
                         password=unhexlify(opts.relay_password).decode('utf-8'), port=opts.relay_port,
                         encryption=opts.encryption,
-                        debug_output=log.debug)
+                        debug_output=safe_debug)
         finally:
             self.last_send_time = time.time()
 
@@ -152,10 +158,8 @@ def email_news(mi, remove, get_fmts, done, job_manager):
         attachment = files[0]
         to_s = [account]
         subjects = [_('News:')+' '+mi.title]
-        texts    = [
-                _('Attached is the %s periodical downloaded by calibre.')
-                    % (mi.title,)
-                ]
+        texts    = [_(
+            'Attached is the %s periodical downloaded by calibre.') % (mi.title,)]
         attachment_names = [ascii_filename(mi.title)+os.path.splitext(attachment)[1]]
         attachments = [attachment]
         jobnames = [mi.title]
@@ -270,7 +274,7 @@ class SelectRecipients(QDialog):  # {{{
         ans = []
         for i in self.items:
             if i.checkState() == Qt.Checked:
-                to = unicode(i.data(Qt.UserRole).toString())
+                to = unicode(i.data(Qt.UserRole) or '')
                 fmts = tuple(x.strip().upper() for x in (opts.accounts[to][0] or '').split(','))
                 subject = opts.subjects.get(to, '')
                 ans.append((to, fmts, subject))
@@ -285,6 +289,9 @@ def select_recipients(parent=None):
 
 class EmailMixin(object):  # {{{
 
+    def __init__(self, *args, **kwargs):
+        pass
+
     def send_multiple_by_mail(self, recipients, delete_from_library):
         ids = set(self.library_view.model().id(r) for r in self.library_view.selectionModel().selectedRows())
         if not ids:
@@ -479,7 +486,7 @@ class EmailMixin(object):  # {{{
 # }}}
 
 if __name__ == '__main__':
-    from PyQt4.Qt import QApplication
+    from PyQt5.Qt import QApplication
     app = QApplication([])  # noqa
     print (select_recipients())
 
