@@ -189,6 +189,7 @@ class RatingDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
         sb.setMinimum(0)
         sb.setMaximum(5)
         sb.setSuffix(' ' + _('stars'))
+        sb.setSpecialValueText(_('Not rated'))
         return sb
 
     def get_required_width(self, editor, style, fm):
@@ -390,6 +391,7 @@ class LanguagesDelegate(QStyledItemDelegate, UpdateEditorGeometry):  # {{{
 
     def setModelData(self, editor, model, index):
         val = ','.join(editor.lang_codes)
+        editor.update_recently_used()
         model.setData(index, (val), Qt.EditRole)
 # }}}
 
