@@ -11,7 +11,7 @@ import os, time, shutil
 from functools import partial
 from threading import Thread
 
-from PyQt4.Qt import (QIcon, QDialog,
+from PyQt5.Qt import (QIcon, QDialog,
         QDialogButtonBox, QLabel, QGridLayout, QPixmap, Qt)
 
 from calibre.gui2.threaded_jobs import ThreadedJob
@@ -53,13 +53,13 @@ class ConfirmDialog(QDialog):
     def __init__(self, ids, parent):
         QDialog.__init__(self, parent)
         self.setWindowTitle(_('Schedule download?'))
-        self.setWindowIcon(QIcon(I('dialog_question.png')))
+        self.setWindowIcon(QIcon(I('download-metadata.png')))
 
         l = self.l = QGridLayout()
         self.setLayout(l)
 
         i = QLabel(self)
-        i.setPixmap(QPixmap(I('dialog_question.png')))
+        i.setPixmap(QPixmap(I('download-metadata.png')))
         l.addWidget(i, 0, 0)
 
         t = QLabel(
