@@ -11,13 +11,13 @@ import os, errno
 from datetime import datetime
 
 from PyQt5.Qt import (Qt, QVBoxLayout, QHBoxLayout, QWidget, QPushButton,
-        QGridLayout, pyqtSignal, QDialogButtonBox, QScrollArea, QFont,
+        QGridLayout, pyqtSignal, QDialogButtonBox, QScrollArea, QFont, QCoreApplication,
         QTabWidget, QIcon, QToolButton, QSplitter, QGroupBox, QSpacerItem,
-        QSizePolicy, QFrame, QSize, QKeySequence, QMenu, QShortcut)
+        QSizePolicy, QFrame, QSize, QKeySequence, QMenu, QShortcut, QDialog)
 
 from calibre.constants import isosx
 from calibre.ebooks.metadata import authors_to_string, string_to_authors
-from calibre.gui2 import ResizableDialog, error_dialog, gprefs, pixmap_to_data
+from calibre.gui2 import error_dialog, gprefs, pixmap_to_data
 from calibre.gui2.metadata.basic_widgets import (TitleEdit, AuthorsEdit,
     AuthorSortEdit, TitleSortEdit, SeriesEdit, SeriesIndexEdit, IdentifiersEdit,
     RatingEdit, PublisherEdit, TagsEdit, FormatsManager, Cover, CommentsEdit,
@@ -35,7 +35,16 @@ fetched_fields = ('title', 'title_sort', 'authors', 'author_sort', 'series',
                   'series_index', 'languages', 'publisher', 'tags', 'rating',
                   'comments', 'pubdate')
 
-class MetadataSingleDialogBase(ResizableDialog):
+class ScrollArea(QScrollArea):
+
+    def __init__(self, widget=None, parent=None):
+        QScrollArea.__init__(self, parent)
+        self.setFrameShape(self.NoFrame)
+        self.setWidgetResizable(True)
+        if widget is not None:
+            self.setWidget(widget)
+
+class MetadataSingleDialogBase(QDialog):
 
     view_format = pyqtSignal(object, object)
     cc_two_column = tweaks['metadata_single_use_2_cols_for_custom_fields']
@@ -50,11 +59,10 @@ class MetadataSingleDialogBase(ResizableDialog):
         self.metadata_before_fetch = None
         self.editing_multiple = editing_multiple
         self.comments_edit_state_at_apply = {}
-        ResizableDialog.__init__(self, parent)
+        QDialog.__init__(self, parent)
+        self.setupUi()
 
     def setupUi(self, *args):  # {{{
-        self.resize(990, 670)
-
         self.download_shortcut = QShortcut(self)
         self.download_shortcut.setKey(QKeySequence('Ctrl+D',
             QKeySequence.PortableText))
@@ -84,15 +92,11 @@ class MetadataSingleDialogBase(ResizableDialog):
         bb.setStandardButtons(bb.Ok|bb.Cancel)
         bb.button(bb.Ok).setDefault(True)
 
-        self.scroll_area = QScrollArea(self)
-        self.scroll_area.setFrameShape(QScrollArea.NoFrame)
-        self.scroll_area.setWidgetResizable(True)
         self.central_widget = QTabWidget(self)
-        self.scroll_area.setWidget(self.central_widget)
 
         self.l = QVBoxLayout(self)
         self.setLayout(self.l)
-        self.l.addWidget(self.scroll_area)
+        self.l.addWidget(self.central_widget)
         ll = self.button_box_layout = QHBoxLayout()
         self.l.addLayout(ll)
         ll.addSpacing(10)
@@ -111,8 +115,16 @@ class MetadataSingleDialogBase(ResizableDialog):
         geom = gprefs.get('metasingle_window_geometry3', None)
         if geom is not None:
             self.restoreGeometry(bytes(geom))
+        else:
+            self.resize(self.sizeHint())
     # }}}
 
+    def sizeHint(self):
+        desktop = QCoreApplication.instance().desktop()
+        geom = desktop.availableGeometry(self)
+        nh, nw = max(300, geom.height()-50), max(400, geom.width()-70)
+        return QSize(nw, nh)
+
     def create_basic_metadata_widgets(self):  # {{{
         self.basic_metadata_widgets = []
 
@@ -579,11 +591,11 @@ class MetadataSingleDialogBase(ResizableDialog):
                     yes_icon='dot_red.png', no_icon='dot_green.png',
                     default_yes=False, skip_dialog_name='edit-metadata-single-confirm-ok-on-multiple'):
                 return self.do_one(delta=1, apply_changes=False)
-        ResizableDialog.accept(self)
+        QDialog.accept(self)
 
     def reject(self):
         self.save_state()
-        ResizableDialog.reject(self)
+        QDialog.reject(self)
 
     def save_state(self):
         try:
@@ -685,14 +697,14 @@ class MetadataSingleDialog(MetadataSingleDialogBase):  # {{{
         self.tabs = []
         self.labels = []
         self.tabs.append(QWidget(self))
-        self.central_widget.addTab(self.tabs[0], _("&Basic metadata"))
+        self.central_widget.addTab(ScrollArea(self.tabs[0], self), _("&Basic metadata"))
         self.tabs[0].l = l = QVBoxLayout()
         self.tabs[0].tl = tl = QGridLayout()
         self.tabs[0].setLayout(l)
         w = getattr(self, 'custom_metadata_widgets_parent', None)
         if w is not None:
             self.tabs.append(w)
-            self.central_widget.addTab(w, _('&Custom metadata'))
+            self.central_widget.addTab(ScrollArea(w, self), _('&Custom metadata'))
         l.addLayout(tl)
         l.addItem(QSpacerItem(10, 15, QSizePolicy.Expanding,
             QSizePolicy.Fixed))
@@ -835,12 +847,12 @@ class MetadataSingleDialogAlt1(MetadataSingleDialogBase):  # {{{
 
         self.on_drag_enter.connect(self.handle_drag_enter)
         self.tabs.append(DragTrackingWidget(self, self.on_drag_enter))
-        self.central_widget.addTab(self.tabs[0], _("&Metadata"))
+        self.central_widget.addTab(ScrollArea(self.tabs[0], self), _("&Metadata"))
         self.tabs[0].l = QGridLayout()
         self.tabs[0].setLayout(self.tabs[0].l)
 
         self.tabs.append(QWidget(self))
-        self.central_widget.addTab(self.tabs[1], _("&Cover and formats"))
+        self.central_widget.addTab(ScrollArea(self.tabs[1], self), _("&Cover and formats"))
         self.tabs[1].l = QGridLayout()
         self.tabs[1].setLayout(self.tabs[1].l)
 
@@ -983,7 +995,7 @@ class MetadataSingleDialogAlt2(MetadataSingleDialogBase):  # {{{
 
         self.central_widget.tabBar().setVisible(False)
         tab0 = QWidget(self)
-        self.central_widget.addTab(tab0, _("&Metadata"))
+        self.central_widget.addTab(ScrollArea(tab0, self), _("&Metadata"))
         l = QGridLayout()
         tab0.setLayout(l)
 
