@@ -20,7 +20,7 @@ from PyQt5.Qt import (
     QStyledItemDelegate, QTextDocument, QRectF, QIcon, Qt, QApplication,
     QDialog, QVBoxLayout, QLabel, QDialogButtonBox, QStyle, QStackedWidget,
     QWidget, QTableView, QGridLayout, QFontInfo, QPalette, QTimer, pyqtSignal,
-    QAbstractTableModel, QSize, QListView, QPixmap, QModelIndex, QUrl,
+    QAbstractTableModel, QSize, QListView, QPixmap, QModelIndex,
     QAbstractListModel, QRect, QTextBrowser, QStringListModel, QMenu,
     QCursor, QHBoxLayout, QPushButton, QSizePolicy)
 from PyQt5.QtWebKitWidgets import QWebView
@@ -31,7 +31,7 @@ from calibre.utils.logging import GUILog as Log
 from calibre.ebooks.metadata.sources.identify import urls_from_identifiers
 from calibre.ebooks.metadata.book.base import Metadata
 from calibre.ebooks.metadata.opf2 import OPF
-from calibre.gui2 import error_dialog, rating_font, gprefs
+from calibre.gui2 import error_dialog, rating_font, gprefs, NO_URL_FORMATTING
 from calibre.gui2.progress_indicator import draw_snake_spinner
 from calibre.utils.date import (utcnow, fromordinal, format_date,
         UNDEFINED_DATE, as_utc)
@@ -324,7 +324,7 @@ class Comments(QWebView):  # {{{
 
     def link_clicked(self, url):
         from calibre.gui2 import open_url
-        if unicode(url.toString(QUrl.None)).startswith('http://'):
+        if unicode(url.toString(NO_URL_FORMATTING)).startswith('http://'):
             open_url(url)
 
     def turnoff_scrollbar(self, *args):
@@ -904,7 +904,7 @@ class CoversWidget(QWidget):  # {{{
         if self.continue_processing:
             self.covers_view.clear_failed()
 
-        if self.worker.error is not None:
+        if self.worker.error and self.worker.error.strip():
             error_dialog(self, _('Download failed'),
                     _('Failed to download any covers, click'
                         ' "Show details" for details.'),
