@@ -50,8 +50,9 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         for signal in ('Activated', 'Changed', 'DoubleClicked', 'Clicked'):
             signal = getattr(self.opt_blocked_auto_formats, 'item'+signal)
             signal.connect(self.blocked_auto_formats_changed)
-        self.tag_map_rules = None
+        self.tag_map_rules = self.add_filter_rules = None
         self.tag_map_rules_button.clicked.connect(self.change_tag_map_rules)
+        self.add_filter_rules_button.clicked.connect(self.change_add_filter_rules)
 
     def change_tag_map_rules(self):
         from calibre.gui2.tag_mapper import RulesDialog
@@ -62,6 +63,15 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
             self.tag_map_rules = d.rules
             self.changed_signal.emit()
 
+    def change_add_filter_rules(self):
+        from calibre.gui2.add_filters import RulesDialog
+        d = RulesDialog(self)
+        if gprefs.get('add_filter_rules'):
+            d.rules = gprefs['add_filter_rules']
+        if d.exec_() == d.Accepted:
+            self.add_filter_rules = d.rules
+            self.changed_signal.emit()
+
     def choose_aa_path(self):
         path = choose_dir(self, 'auto add path choose',
                 _('Choose a folder'))
@@ -75,7 +85,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.filename_pattern.blockSignals(False)
         self.init_blocked_auto_formats()
         self.opt_automerge.setEnabled(self.opt_add_formats_to_existing.isChecked())
-        self.tag_map_rules = None
+        self.tag_map_rules = self.add_filter_rules = None
 
     # Blocked auto formats {{{
     def blocked_auto_formats_changed(self, *args):
@@ -115,6 +125,8 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         ConfigWidgetBase.restore_defaults(self)
         self.filename_pattern.initialize(defaults=True)
         self.init_blocked_auto_formats(defaults=True)
+        self.tag_map_rules = []
+        self.add_filter_rules = []
 
     def commit(self):
         path = unicode(self.opt_auto_add_path.text()).strip()
@@ -150,12 +162,19 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
                 gprefs['tag_map_on_add_rules'] = self.tag_map_rules
             else:
                 gprefs.pop('tag_map_on_add_rules', None)
+        if self.add_filter_rules is not None:
+            if self.add_filter_rules:
+                gprefs['add_filter_rules'] = self.add_filter_rules
+            else:
+                gprefs.pop('add_filter_rules', None)
         ret = ConfigWidgetBase.commit(self)
         return changed or ret
 
     def refresh_gui(self, gui):
         # Ensure worker process reads updated settings
         gui.spare_pool().shutdown()
+        # Update rules used int he auto adder
+        gui.auto_adder.read_rules()
 
 if __name__ == '__main__':
     from PyQt5.Qt import QApplication
