@@ -10,11 +10,11 @@ __docformat__ = 'restructuredtext en'
 import os, textwrap
 from functools import partial
 
-from PyQt4.Qt import (QWidget, QDialog, QLabel, QGridLayout, QComboBox, QSize,
+from PyQt5.Qt import (QWidget, QDialog, QLabel, QGridLayout, QComboBox, QSize,
         QLineEdit, QIntValidator, QDoubleValidator, QFrame, Qt, QIcon,
         QScrollArea, QPushButton, QVBoxLayout, QDialogButtonBox, QToolButton,
         QListView, QAbstractListModel, pyqtSignal, QSizePolicy, QSpacerItem,
-        QApplication, QStandardItem, QStandardItemModel, QCheckBox, QMenu)
+        QApplication, QStandardItem, QStandardItemModel, QCheckBox, QMenu, QPixmap)
 
 from calibre import prepare_string_for_xml, sanitize_file_name_unicode
 from calibre.constants import config_dir
@@ -35,7 +35,6 @@ icon_rule_kinds = [(_('icon with text'), 'icon'),
                    (_('composed icons w/text'), 'icon_composed'),
                    (_('composed icons w/no text'), 'icon_only_composed'),]
 
-
 class ConditionEditor(QWidget):  # {{{
 
     ACTION_MAP = {
@@ -140,10 +139,10 @@ class ConditionEditor(QWidget):  # {{{
     def current_col(self):
         def fget(self):
             idx = self.column_box.currentIndex()
-            return unicode(self.column_box.itemData(idx).toString())
+            return unicode(self.column_box.itemData(idx) or '')
         def fset(self, val):
             for idx in range(self.column_box.count()):
-                c = unicode(self.column_box.itemData(idx).toString())
+                c = unicode(self.column_box.itemData(idx) or '')
                 if c == val:
                     self.column_box.setCurrentIndex(idx)
                     return
@@ -154,10 +153,10 @@ class ConditionEditor(QWidget):  # {{{
     def current_action(self):
         def fget(self):
             idx = self.action_box.currentIndex()
-            return unicode(self.action_box.itemData(idx).toString())
+            return unicode(self.action_box.itemData(idx) or '')
         def fset(self, val):
             for idx in range(self.action_box.count()):
-                c = unicode(self.action_box.itemData(idx).toString())
+                c = unicode(self.action_box.itemData(idx) or '')
                 if c == val:
                     self.action_box.setCurrentIndex(idx)
                     return
@@ -304,7 +303,7 @@ class RuleEditor(QDialog):  # {{{
         self.setLayout(l)
 
         self.l1 = l1 = QLabel(_('Create a {0} rule by'
-            ' filling in the boxes below'.format(rule_text)))
+            ' filling in the boxes below').format(rule_text))
         l.addWidget(l1, 0, 0, 1, 8)
 
         self.f1 = QFrame(self)
@@ -341,6 +340,10 @@ class RuleEditor(QDialog):  # {{{
 
         def create_filename_box():
             self.filename_box = f = QComboBox()
+            self.filenamebox_view = v = QListView()
+            v.setIconSize(QSize(32, 32))
+            self.filename_box.setView(v)
+            self.orig_filenamebox_view = f.view()
             f.setMinimumContentsLength(20), f.setSizeAdjustPolicy(f.AdjustToMinimumContentsLengthWithIcon)
             self.populate_icon_filenames()
 
@@ -463,8 +466,10 @@ class RuleEditor(QDialog):  # {{{
         self.icon_file_names.sort(key=sort_key)
         if doing_multiple:
             item = QStandardItem(_('Open to see checkboxes'))
+            item.setIcon(QIcon(I('blank.png')))
         else:
             item = QStandardItem('')
+        item.setFlags(Qt.ItemFlag(0))
         model.appendRow(item)
 
         for i,filename in enumerate(self.icon_file_names):
@@ -474,7 +479,7 @@ class RuleEditor(QDialog):  # {{{
                 item.setData(Qt.Unchecked, Qt.CheckStateRole)
             else:
                 item.setFlags(Qt.ItemIsEnabled | Qt.ItemIsSelectable)
-            icon = QIcon(os.path.join(self.icon_folder, filename))
+            icon = QIcon(QPixmap(os.path.join(self.icon_folder, filename)).scaled(self.filenamebox_view.iconSize(), transformMode=Qt.SmoothTransformation))
             item.setIcon(icon)
             model.appendRow(item)
 
@@ -488,21 +493,23 @@ class RuleEditor(QDialog):  # {{{
             <span style="color: {c}; background-color: {bg2}">&nbsp;{st}&nbsp;</span>
             '''.format(c=c, bg1=bg1, bg2=bg2, st=_('Sample Text')))
 
+    def sanitize_icon_file_name(self, icon_path):
+        n = lower(sanitize_file_name_unicode(
+                             os.path.splitext(
+                                   os.path.basename(icon_path))[0]+'.png'))
+        return n.replace("'", '_')
+
     def filename_button_clicked(self):
         try:
             path = choose_files(self, 'choose_category_icon',
                         _('Select Icon'), filters=[
-                        ('Images', ['png', 'gif', 'jpg', 'jpeg'])],
+                        (_('Images'), ['png', 'gif', 'jpg', 'jpeg'])],
                     all_files=False, select_only_single_file=True)
             if path:
                 icon_path = path[0]
-                icon_name = lower(sanitize_file_name_unicode(
-                             os.path.splitext(
-                                   os.path.basename(icon_path))[0]+'.png'))
+                icon_name = self.sanitize_icon_file_name(icon_path)
                 if icon_name not in self.icon_file_names:
                     self.icon_file_names.append(icon_name)
-                    self.update_filename_box()
-                    self.update_remove_button()
                     try:
                         p = QIcon(icon_path).pixmap(QSize(128, 128))
                         d = self.icon_folder
@@ -514,6 +521,8 @@ class RuleEditor(QDialog):  # {{{
                     except:
                         import traceback
                         traceback.print_exc()
+                    self.update_filename_box()
+                    self.update_remove_button()
                 if self.doing_multiple:
                     if icon_name not in self.rule_icon_files:
                         self.rule_icon_files.append(icon_name)
@@ -595,7 +604,7 @@ class RuleEditor(QDialog):  # {{{
             self.update_icon_filenames_in_box()
 
         for i in range(self.column_box.count()):
-            c = unicode(self.column_box.itemData(i).toString())
+            c = unicode(self.column_box.itemData(i) or '')
             if col == c:
                 self.column_box.setCurrentIndex(i)
                 break
@@ -649,14 +658,14 @@ class RuleEditor(QDialog):  # {{{
         else:
             r.color = self.color_box.color
         idx = self.column_box.currentIndex()
-        col = unicode(self.column_box.itemData(idx).toString())
+        col = unicode(self.column_box.itemData(idx) or '')
         for c in self.conditions:
             condition = c.condition
             if condition is not None:
                 r.add_condition(*condition)
         if self.rule_kind == 'icon':
             kind = unicode(self.kind_box.itemData(
-                                    self.kind_box.currentIndex()).toString())
+                                    self.kind_box.currentIndex()) or '')
         else:
             kind = self.rule_kind
 
@@ -683,7 +692,7 @@ class RulesModel(QAbstractListModel):  # {{{
                     rule = template
                 self.rules.append(('color', col, rule))
         else:
-            self.rule_kind = 'icon'
+            self.rule_kind = 'icon' if pref_name == 'column_icon_rules' else 'emblem'
             rules = list(prefs[pref_name])
             self.rules = []
             for kind, col, template in rules:
@@ -714,8 +723,9 @@ class RulesModel(QAbstractListModel):  # {{{
             return (kind, col, rule)
 
     def add_rule(self, kind, col, rule):
+        self.beginResetModel()
         self.rules.append((kind, col, rule))
-        self.reset()
+        self.endResetModel()
         return self.index(len(self.rules)-1)
 
     def replace_rule(self, index, kind, col, r):
@@ -723,8 +733,9 @@ class RulesModel(QAbstractListModel):  # {{{
         self.dataChanged.emit(index, index)
 
     def remove_rule(self, index):
+        self.beginResetModel()
         self.rules.remove(self.rules[index.row()])
-        self.reset()
+        self.endResetModel()
 
     def commit(self, prefs):
         rules = []
@@ -751,7 +762,8 @@ class RulesModel(QAbstractListModel):  # {{{
 
     def clear(self):
         self.rules = []
-        self.reset()
+        self.beginResetModel()
+        self.endResetModel()
 
     def rule_to_html(self, kind, col, rule):
         trans_kind = 'not found'
@@ -769,6 +781,11 @@ class RulesModel(QAbstractListModel):  # {{{
                 <p>Advanced Rule for column <b>%(col)s</b>:
                 <pre>%(rule)s</pre>
                 ''')%dict(col=col, rule=prepare_string_for_xml(rule))
+            elif self.rule_kind == 'emblem':
+                return _('''
+                <p>Advanced Rule:
+                <pre>%(rule)s</pre>
+                ''')%dict(rule=prepare_string_for_xml(rule))
             else:
                 return _('''
                 <p>Advanced Rule: set <b>%(typ)s</b> for column <b>%(col)s</b>:
@@ -819,6 +836,10 @@ class RulesModel(QAbstractListModel):  # {{{
                 else:
                     continue
                 break
+        if action_name == Rule.INVALID_CONDITION:
+            return (
+                _('<li>The condition using column <b>%(col)s</b> is <b>invalid</b>')
+                % dict(col=c))
         return (
             _('<li>If the <b>%(col)s</b> column <b>%(action)s</b> value: <b>%(val)s</b>') % dict(
                 col=c, action=action_name, val=prepare_string_for_xml(v)))
@@ -847,7 +868,7 @@ class EditRules(QWidget):  # {{{
         self.add_button = QPushButton(QIcon(I('plus.png')), _('Add Rule'),
                 self)
         self.remove_button = QPushButton(QIcon(I('minus.png')),
-                _('Remove Rule'), self)
+                _('Remove Rule(s)'), self)
         self.add_button.clicked.connect(self.add_rule)
         self.remove_button.clicked.connect(self.remove_rule)
         l.addWidget(self.add_button, l.rowCount(), 0)
@@ -856,7 +877,7 @@ class EditRules(QWidget):  # {{{
         self.g = g = QGridLayout()
         self.rules_view = QListView(self)
         self.rules_view.doubleClicked.connect(self.edit_rule)
-        self.rules_view.setSelectionMode(self.rules_view.SingleSelection)
+        self.rules_view.setSelectionMode(self.rules_view.ExtendedSelection)
         self.rules_view.setAlternatingRowColors(True)
         self.rtfd = RichTextDelegate(parent=self.rules_view, max_width=400)
         self.rules_view.setItemDelegate(self.rtfd)
@@ -912,7 +933,7 @@ class EditRules(QWidget):  # {{{
             self.enabled.setText(_('Show &emblems next to the covers'))
             self.enabled.stateChanged.connect(self.enabled_toggled)
             self.enabled.setToolTip(_(
-                'If checked, you can tell calibre to displays icons of your choosing'
+                'If checked, you can tell calibre to display icons of your choosing'
                 ' next to the covers shown in the cover grid, controlled by the'
                 ' metadata of the book.'))
             self.enabled_toggled()
@@ -943,9 +964,11 @@ class EditRules(QWidget):  # {{{
                     self.rules_view.scrollTo(idx)
                     self.changed.emit()
         else:
-            td = TemplateDialog(self, '', mi=self.mi, fm=self.fm, icon_field_key='')
+            if self.pref_name == 'cover_grid_icon_rules':
+                td = TemplateDialog(self, '', mi=self.mi, fm=self.fm, doing_emblem=True)
+            else:
+                td = TemplateDialog(self, '', mi=self.mi, fm=self.fm, icon_field_key='')
             if td.exec_() == td.Accepted:
-                print(td.rule)
                 typ, col, r = td.rule
                 if typ and r and col:
                     idx = self.model.add_rule(typ, col, r)
@@ -962,6 +985,8 @@ class EditRules(QWidget):  # {{{
             d.apply_rule(kind, col, rule)
         elif self.pref_name == 'column_color_rules':
             d = TemplateDialog(self, rule, mi=self.mi, fm=self.fm, color_field=col)
+        elif self.pref_name == 'cover_grid_icon_rules':
+            d = TemplateDialog(self, rule, mi=self.mi, fm=self.fm, doing_emblem=True)
         else:
             d = TemplateDialog(self, rule, mi=self.mi, fm=self.fm, icon_field_key=col,
                                icon_rule_kind=kind)
@@ -982,12 +1007,13 @@ class EditRules(QWidget):  # {{{
             error_dialog(self, _('No rule selected'),
                     _('No rule selected for %s.')%txt, show=True)
             return None
-        return rows[0]
+        return sorted(rows, reverse=True)
 
     def remove_rule(self):
-        row = self.get_selected_row(_('removal'))
-        if row is not None:
-            self.model.remove_rule(row)
+        rows = self.get_selected_row(_('removal'))
+        if rows is not None:
+            for row in rows:
+                self.model.remove_rule(row)
             self.changed.emit()
 
     def move_up(self):
@@ -1029,7 +1055,7 @@ if __name__ == '__main__':
     db = db()
 
     if True:
-        d = RuleEditor(db.field_metadata, 'column_color_rules')
+        d = RuleEditor(db.field_metadata, 'column_icon_rules')
         d.add_blank_condition()
         d.exec_()
 
