@@ -5,7 +5,7 @@ __license__   = 'GPL v3'
 __copyright__ = '2010, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
-from PyQt4.Qt import QApplication
+from PyQt5.Qt import QApplication
 
 from calibre.gui2.preferences import ConfigWidgetBase, test_widget, \
         CommaSeparatedList
@@ -96,7 +96,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.gst_changed = False
 
         if db.prefs.get('grouped_search_make_user_categories', None) is None:
-            db.prefs.set('grouped_search_make_user_categories', [])
+            db.new_api.set_pref('grouped_search_make_user_categories', [])
         r('grouped_search_make_user_categories', db.prefs, setting=CommaSeparatedList)
         self.muc_changed = False
         self.opt_grouped_search_make_user_categories.lineEdit().editingFinished.connect(
@@ -141,7 +141,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
                                 _('The search term cannot be blank'),
                                 show=True)
         if idx != 0:
-            orig_name = unicode(self.gst_names.itemData(idx).toString())
+            orig_name = unicode(self.gst_names.itemData(idx) or '')
         else:
             orig_name = ''
         if name != orig_name:
@@ -206,21 +206,21 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         if idx == 0:
             self.gst_value.setText('')
         else:
-            name = unicode(self.gst_names.itemData(idx).toString())
+            name = unicode(self.gst_names.itemData(idx) or '')
             self.gst_value.setText(','.join(self.gst[name]))
         self.gst_value.blockSignals(False)
 
     def commit(self):
         if self.gst_changed:
-            self.db.prefs.set('grouped_search_terms', self.gst)
+            self.db.new_api.set_pref('grouped_search_terms', self.gst)
             self.db.field_metadata.add_grouped_search_terms(self.gst)
-        self.db.prefs.set('similar_authors_search_key',
+        self.db.new_api.set_pref('similar_authors_search_key',
                           unicode(self.similar_authors_search_key.currentText()))
-        self.db.prefs.set('similar_tags_search_key',
+        self.db.new_api.set_pref('similar_tags_search_key',
                           unicode(self.similar_tags_search_key.currentText()))
-        self.db.prefs.set('similar_series_search_key',
+        self.db.new_api.set_pref('similar_series_search_key',
                           unicode(self.similar_series_search_key.currentText()))
-        self.db.prefs.set('similar_publisher_search_key',
+        self.db.new_api.set_pref('similar_publisher_search_key',
                           unicode(self.similar_publisher_search_key.currentText()))
         return ConfigWidgetBase.commit(self)
 
