@@ -7,11 +7,11 @@ __docformat__ = 'restructuredtext en'
 
 from functools import partial
 
-from PyQt4.Qt import QAbstractListModel, Qt, QIcon, \
-        QVariant, QItemSelectionModel
+from PyQt5.Qt import QAbstractListModel, Qt, QIcon, \
+        QItemSelectionModel
 
 from calibre.gui2.preferences.toolbar_ui import Ui_Form
-from calibre.gui2 import gprefs, NONE, warning_dialog
+from calibre.gui2 import gprefs, warning_dialog
 from calibre.gui2.preferences import ConfigWidgetBase, test_widget
 
 
@@ -58,19 +58,19 @@ class BaseModel(QAbstractListModel):
             text = text.replace('&', '')
             if text == _('%d books'):
                 text = _('Choose library')
-            return QVariant(text)
+            return (text)
         if role == Qt.DecorationRole:
             if hasattr(self._data[row], 'qaction'):
                 icon = self._data[row].qaction.icon()
                 if not icon.isNull():
-                    return QVariant(icon)
+                    return (icon)
             ic = action[1]
             if ic is None:
                 ic = 'blank.png'
-            return QVariant(QIcon(I(ic)))
+            return (QIcon(I(ic)))
         if role == Qt.ToolTipRole and action[2] is not None:
-            return QVariant(action[2])
-        return NONE
+            return (action[2])
+        return None
 
     def names(self, indexes):
         rows = [i.row() for i in indexes]
@@ -110,31 +110,36 @@ class AllModel(BaseModel):
     def add(self, names):
         actions = []
         for name in names:
-            if name is None or name.startswith('---'): continue
+            if name is None or name.startswith('---'):
+                continue
             actions.append(self.name_to_action(name, self.gui))
+        self.beginResetModel()
         self._data.extend(actions)
         self._data.sort()
-        self.reset()
+        self.endResetModel()
 
     def remove(self, indices, allowed):
         rows = [i.row() for i in indices]
         remove = set([])
         for row in rows:
             ac = self._data[row]
-            if ac.name.startswith('---'): continue
+            if ac.name.startswith('---'):
+                continue
             if ac.name in allowed:
                 remove.add(row)
         ndata = []
         for i, ac in enumerate(self._data):
             if i not in remove:
                 ndata.append(ac)
+        self.beginResetModel()
         self._data = ndata
-        self.reset()
+        self.endResetModel()
 
     def restore_defaults(self):
         current = gprefs.defaults[self.gprefs_name]
+        self.beginResetModel()
         self._data = self.get_all_actions(current)
-        self.reset()
+        self.endResetModel()
 
 class CurrentModel(BaseModel):
 
@@ -172,8 +177,9 @@ class CurrentModel(BaseModel):
             else:
                 actions.append(ac)
 
+        self.beginResetModel()
         self._data.extend(actions)
-        self.reset()
+        self.endResetModel()
         return reject
 
     def remove(self, indices):
@@ -189,8 +195,9 @@ class CurrentModel(BaseModel):
         for i, ac in enumerate(self._data):
             if i not in remove:
                 ndata.append(ac)
+        self.beginResetModel()
         self._data = ndata
-        self.reset()
+        self.endResetModel()
         return rejected
 
     def commit(self):
@@ -211,8 +218,9 @@ class CurrentModel(BaseModel):
 
     def restore_defaults(self):
         current = gprefs.defaults[self.gprefs_name]
+        self.beginResetModel()
         self._data =  [self.name_to_action(x, self.gui) for x in current]
-        self.reset()
+        self.endResetModel()
 
 
 class ConfigWidget(ConfigWidgetBase, Ui_Form):
@@ -254,15 +262,15 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.current_actions.entered.connect(self.current_entered)
 
     def all_entered(self, index):
-        tt = self.all_actions.model().data(index, Qt.ToolTipRole).toString()
+        tt = self.all_actions.model().data(index, Qt.ToolTipRole) or ''
         self.help_text.setText(tt)
 
     def current_entered(self, index):
-       tt = self.current_actions.model().data(index, Qt.ToolTipRole).toString()
-       self.help_text.setText(tt)
+        tt = self.current_actions.model().data(index, Qt.ToolTipRole) or ''
+        self.help_text.setText(tt)
 
     def what_changed(self, idx):
-        key = unicode(self.what.itemData(idx).toString())
+        key = unicode(self.what.itemData(idx) or '')
         if key == 'blank':
             self.actions_widget.setVisible(False)
             self.spacer_widget.setVisible(True)
@@ -349,7 +357,6 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
 
 
 if __name__ == '__main__':
-    from PyQt4.Qt import QApplication
+    from PyQt5.Qt import QApplication
     app = QApplication([])
     test_widget('Interface', 'Toolbar')
-
