@@ -11,7 +11,7 @@ from collections import OrderedDict
 
 from calibre.gui2.preferences import ConfigWidgetBase, test_widget, AbortCommit
 from calibre.gui2.preferences.tweaks_ui import Ui_Form
-from calibre.gui2 import error_dialog, NONE, info_dialog
+from calibre.gui2 import error_dialog, info_dialog
 from calibre.utils.config import read_raw_tweaks, write_tweaks
 from calibre.gui2.widgets import PythonHighlighter
 from calibre import isbytestring
@@ -19,12 +19,17 @@ from calibre.utils.icu import lower
 from calibre.utils.search_query_parser import (ParseException,
         SearchQueryParser)
 
-from PyQt4.Qt import (QAbstractListModel, Qt, QStyledItemDelegate, QStyle,
+from PyQt5.Qt import (QAbstractListModel, Qt, QStyledItemDelegate, QStyle,
     QStyleOptionViewItem, QFont, QDialogButtonBox, QDialog, QApplication,
     QVBoxLayout, QPlainTextEdit, QLabel, QModelIndex, QMenu, QIcon)
 
 ROOT = QModelIndex()
 
+class AdaptSQP(SearchQueryParser):
+
+    def __init__(self, *args, **kwargs):
+        pass
+
 class Delegate(QStyledItemDelegate):  # {{{
     def __init__(self, view):
         QStyledItemDelegate.__init__(self, view)
@@ -98,7 +103,7 @@ class Tweak(object):  # {{{
 
 # }}}
 
-class Tweaks(QAbstractListModel, SearchQueryParser):  # {{{
+class Tweaks(QAbstractListModel, AdaptSQP):  # {{{
 
     def __init__(self, parent=None):
         QAbstractListModel.__init__(self, parent)
@@ -115,7 +120,7 @@ class Tweaks(QAbstractListModel, SearchQueryParser):  # {{{
         try:
             tweak = self.tweaks[row]
         except:
-            return NONE
+            return None
         if role == Qt.DisplayRole:
             return textwrap.fill(tweak.name, 40)
         if role == Qt.FontRole and tweak.is_customized:
@@ -132,7 +137,7 @@ class Tweaks(QAbstractListModel, SearchQueryParser):  # {{{
             return textwrap.fill(tt)
         if role == Qt.UserRole:
             return tweak
-        return NONE
+        return None
 
     def parse_tweaks(self, defaults, custom):
         l, g = {}, {}
@@ -195,7 +200,7 @@ class Tweaks(QAbstractListModel, SearchQueryParser):  # {{{
 
     def restore_to_default(self, idx):
         tweak = self.data(idx, Qt.UserRole)
-        if tweak is not NONE:
+        if tweak is not None:
             tweak.restore_to_default()
             self.dataChanged.emit(idx, idx)
 
@@ -206,7 +211,7 @@ class Tweaks(QAbstractListModel, SearchQueryParser):  # {{{
 
     def update_tweak(self, idx, varmap):
         tweak = self.data(idx, Qt.UserRole)
-        if tweak is not NONE:
+        if tweak is not None:
             tweak.update(varmap)
             self.dataChanged.emit(idx, idx)
 
@@ -294,6 +299,7 @@ class PluginTweaks(QDialog):  # {{{
 
     def __init__(self, raw, parent=None):
         QDialog.__init__(self, parent)
+        self.setWindowTitle(_('Plugin tweaks'))
         self.edit = QPlainTextEdit(self)
         self.highlighter = PythonHighlighter(self.edit.document())
         self.l = QVBoxLayout()
