@@ -10,9 +10,10 @@ import re, time
 from functools import partial
 
 
-from PyQt5.Qt import QComboBox, Qt, QLineEdit, pyqtSlot, QDialog, \
-                     pyqtSignal, QCompleter, QAction, QKeySequence, QTimer, \
-                     QIcon, QMenu
+from PyQt5.Qt import (
+    QComboBox, Qt, QLineEdit, pyqtSlot, QDialog,
+    pyqtSignal, QCompleter, QAction, QKeySequence, QTimer,
+    QIcon, QMenu, QApplication, QKeyEvent)
 
 from calibre.gui2 import config, error_dialog, question_dialog, gprefs
 from calibre.gui2.dialogs.confirm_delete import confirm
@@ -40,7 +41,22 @@ class SearchLineEdit(QLineEdit):  # {{{
 
     def contextMenuEvent(self, ev):
         self.parent().normalize_state()
-        return QLineEdit.contextMenuEvent(self, ev)
+        menu = self.createStandardContextMenu()
+        menu.setAttribute(Qt.WA_DeleteOnClose)
+        for action in menu.actions():
+            if action.text().startswith(_('&Paste') + '\t'):
+                break
+        ac = menu.addAction(_('Paste and &search'))
+        ac.setEnabled(bool(QApplication.clipboard().text()))
+        ac.setIcon(QIcon(I('search.png')))
+        ac.triggered.connect(self.paste_and_search)
+        menu.insertAction(action, ac)
+        menu.exec_(ev.globalPos())
+
+    def paste_and_search(self):
+        self.paste()
+        ev = QKeyEvent(QKeyEvent.KeyPress, Qt.Key_Enter, Qt.NoModifier)
+        self.keyPressEvent(ev)
 
     @pyqtSlot()
     def paste(self, *args):
@@ -318,6 +334,7 @@ class SavedSearchBox(QComboBox):  # {{{
         QComboBox.clear(self)
         self.initialize_saved_search_names()
         self.setEditText('')
+        self.setToolTip(self.tool_tip_text)
         self.line_edit.home(False)
 
     def key_pressed(self, event):
@@ -509,9 +526,9 @@ class SavedSearchBoxMixin(object):  # {{{
         # self.saved_searches_changed()
         self.saved_search.initialize(self.search, colorize=True,
                 help_text=_('Saved Searches'))
-        self.saved_search.setToolTip(
-            _('Choose saved search or enter name for new saved search'))
-        self.saved_search.setStatusTip(self.saved_search.toolTip())
+        self.saved_search.tool_tip_text=_('Choose saved search or enter name for new saved search')
+        self.saved_search.setToolTip(self.saved_search.tool_tip_text)
+        self.saved_search.setStatusTip(self.saved_search.tool_tip_text)
         for x in ('copy', 'save'):
             b = getattr(self, x+'_search_button')
             b.setStatusTip(b.toolTip())
