@@ -11,25 +11,25 @@ import cPickle, os
 from functools import partial
 from itertools import izip
 
-from PyQt4.Qt import (QStyledItemDelegate, Qt, QTreeView, pyqtSignal, QSize,
+from PyQt5.Qt import (QStyledItemDelegate, Qt, QTreeView, pyqtSignal, QSize,
         QIcon, QApplication, QMenu, QPoint, QModelIndex, QToolTip, QCursor,
         QDrag)
 
 from calibre import sanitize_file_name_unicode
 from calibre.constants import config_dir
 from calibre.gui2.tag_browser.model import (TagTreeItem, TAG_SEARCH_STATES,
-        TagsModel)
+        TagsModel, DRAG_IMAGE_ROLE)
 from calibre.gui2 import config, gprefs, choose_files, pixmap_to_data
 from calibre.utils.icu import sort_key
 
-class TagDelegate(QStyledItemDelegate): # {{{
+class TagDelegate(QStyledItemDelegate):  # {{{
 
     def __init__(self, *args, **kwargs):
         QStyledItemDelegate.__init__(self, *args, **kwargs)
         self.old_look = gprefs['tag_browser_old_look']
 
     def paint(self, painter, option, index):
-        item = index.data(Qt.UserRole).toPyObject()
+        item = index.data(Qt.UserRole)
         QStyledItemDelegate.paint(self, painter, option, index)
         widget = self.parent()
         style = QApplication.style() if widget is None else widget.style()
@@ -42,13 +42,14 @@ class TagDelegate(QStyledItemDelegate): # {{{
             painter.restore()
         if item.type != TagTreeItem.TAG:
             return
-        if (item.tag.state == 0 and config['show_avg_rating'] and
-                item.tag.avg_rating is not None):
+        if item.tag.state == 0 and config['show_avg_rating']:
+            rating = item.average_rating
+            if rating is None:
+                return
             r = style.subElementRect(style.SE_ItemViewItemDecoration,
                     option, widget)
             icon = option.icon
             painter.save()
-            rating = item.tag.avg_rating
             nr = r.adjusted(0, 0, 0, 0)
             nr.setBottom(r.bottom()-int(r.height()*(rating/5.0)))
             painter.setClipRect(nr)
@@ -65,10 +66,9 @@ class TagDelegate(QStyledItemDelegate): # {{{
                     icon.On)
             painter.restore()
 
-
     # }}}
 
-class TagsView(QTreeView): # {{{
+class TagsView(QTreeView):  # {{{
 
     refresh_required        = pyqtSignal()
     tags_marked             = pyqtSignal(object)
@@ -85,14 +85,14 @@ class TagsView(QTreeView): # {{{
     search_item_renamed     = pyqtSignal()
     drag_drop_finished      = pyqtSignal(object)
     restriction_error       = pyqtSignal()
-    tag_item_delete         = pyqtSignal(object, object, object)
+    tag_item_delete         = pyqtSignal(object, object, object, object)
 
     def __init__(self, parent=None):
         QTreeView.__init__(self, parent=None)
+        self.setMouseTracking(True)
         self.alter_tb = None
         self.disable_recounting = False
         self.setUniformRowHeights(True)
-        self.setCursor(Qt.PointingHandCursor)
         self.setIconSize(QSize(20, 20))
         self.setTabKeyNavigation(True)
         self.setAnimated(True)
@@ -130,8 +130,8 @@ class TagsView(QTreeView): # {{{
         self.setStyleSheet('''
                 QTreeView::item {
                     border: 1px solid transparent;
-                    padding-top:0.9ex;
-                    padding-bottom:0.9ex;
+                    padding-top:0.8ex;
+                    padding-bottom:0.8ex;
                 }
 
                 QTreeView::item:hover {
@@ -142,6 +142,9 @@ class TagsView(QTreeView): # {{{
         ''' + ('' if gprefs['tag_browser_old_look'] else stylish_tb))
         if gprefs['tag_browser_old_look']:
             self.setAlternatingRowColors(True)
+        # Allowing keyboard focus looks bad in the Qt Fusion style and is useless
+        # anyway since the enter/spacebar keys do nothing
+        self.setFocusPolicy(Qt.NoFocus)
 
     @property
     def hidden_categories(self):
@@ -178,7 +181,7 @@ class TagsView(QTreeView): # {{{
     def set_database(self, db, alter_tb):
         self._model.set_database(db)
         self.alter_tb = alter_tb
-        self.pane_is_visible = True # because TagsModel.set_database did a recount
+        self.pane_is_visible = True  # because TagsModel.set_database did a recount
         self.setModel(self._model)
         self.setContextMenuPolicy(Qt.CustomContextMenu)
         pop = self.db.CATEGORY_SORTS.index(config['sort_tags_by'])
@@ -206,7 +209,7 @@ class TagsView(QTreeView): # {{{
 
     def user_categories_edited(self, user_cats, nkey):
         state_map = self.get_state()[1]
-        self.db.prefs.set('user_categories', user_cats)
+        self.db.new_api.set_pref('user_categories', user_cats)
         self._model.rebuild_node_tree(state_map=state_map)
         p = self._model.find_category_node('@'+nkey)
         self.show_item_at_path(p)
@@ -233,6 +236,12 @@ class TagsView(QTreeView): # {{{
 
     def mouseMoveEvent(self, event):
         dex = self.indexAt(event.pos())
+        if dex.isValid():
+            self.setCursor(Qt.PointingHandCursor)
+        else:
+            self.unsetCursor()
+        if not event.buttons() & Qt.LeftButton:
+            return
         if self.in_drag_drop or not dex.isValid():
             QTreeView.mouseMoveEvent(self, event)
             return
@@ -246,7 +255,7 @@ class TagsView(QTreeView): # {{{
             QTreeView.mouseMoveEvent(self, event)
             return
         md = self._model.mimeData([dex])
-        pixmap = dex.data(Qt.DecorationRole).toPyObject().pixmap(25, 25)
+        pixmap = dex.data(DRAG_IMAGE_ROLE).pixmap(self.iconSize())
         drag = QDrag(self)
         drag.setPixmap(pixmap)
         drag.setMimeData(md)
@@ -271,6 +280,11 @@ class TagsView(QTreeView): # {{{
         joiner = ' and ' if self.match_all else ' or '
         return joiner.join(tokens)
 
+    def toggle_current_index(self):
+        ci = self.currentIndex()
+        if ci.isValid():
+            self.toggle(ci)
+
     def toggle(self, index):
         self._toggle(index, None)
 
@@ -289,7 +303,8 @@ class TagsView(QTreeView): # {{{
             self.clear()
 
     def context_menu_handler(self, action=None, category=None,
-                             key=None, index=None, search_state=None):
+                             key=None, index=None, search_state=None,
+                             use_vl=None):
         if not action:
             return
         try:
@@ -320,11 +335,22 @@ class TagsView(QTreeView): # {{{
                 self.recount()
                 return
 
-            if action == 'edit_item':
+            if action == 'edit_item_no_vl':
+                item = self.model().get_node(index)
+                item.use_vl = False
                 self.edit(index)
                 return
-            if action == 'delete_item':
-                self.tag_item_delete.emit(key, index.id, index.original_name)
+            if action == 'edit_item_in_vl':
+                item = self.model().get_node(index)
+                item.use_vl = True
+                self.edit(index)
+                return
+            if action == 'delete_item_in_vl':
+                self.tag_item_delete.emit(key, index.id, index.original_name,
+                                          self.model().get_book_ids_to_use())
+                return
+            if action == 'delete_item_no_vl':
+                self.tag_item_delete.emit(key, index.id, index.original_name, None)
                 return
             if action == 'open_editor':
                 self.tags_list_edit.emit(category, key)
@@ -388,7 +414,7 @@ class TagsView(QTreeView): # {{{
                     gprefs['tags_browser_partition_method'] = category
             elif action == 'defaults':
                 self.hidden_categories.clear()
-            self.db.prefs.set('tag_browser_hidden_categories', list(self.hidden_categories))
+            self.db.new_api.set_pref('tag_browser_hidden_categories', list(self.hidden_categories))
             if reset_filter_categories:
                 self._model.set_categories_filter(None)
             self._model.rebuild_node_tree()
@@ -396,7 +422,7 @@ class TagsView(QTreeView): # {{{
             return
 
     def show_context_menu(self, point):
-        def display_name( tag):
+        def display_name(tag):
             if tag.category == 'search':
                 n = tag.name
                 if len(n) > 45:
@@ -408,7 +434,7 @@ class TagsView(QTreeView): # {{{
         self.context_menu = QMenu(self)
 
         if index.isValid():
-            item = index.data(Qt.UserRole).toPyObject()
+            item = index.data(Qt.UserRole)
             tag = None
 
             if item.type == TagTreeItem.TAG:
@@ -421,7 +447,7 @@ class TagsView(QTreeView): # {{{
                 if not item.category_key.startswith('@'):
                     while item.parent != self._model.root_item:
                         item = item.parent
-                category = unicode(item.name.toString())
+                category = unicode(item.name or '')
                 key = item.category_key
                 # Verify that we are working with a field that we know something about
                 if key not in self.db.field_metadata:
@@ -433,15 +459,26 @@ class TagsView(QTreeView): # {{{
                     # the possibility of renaming that item.
                     if tag.is_editable:
                         # Add the 'rename' items
+                        if self.model().get_in_vl():
+                            self.context_menu.addAction(self.rename_icon,
+                                                    _('Rename %s in virtual library')%display_name(tag),
+                                    partial(self.context_menu_handler, action='edit_item_in_vl',
+                                            index=index))
                         self.context_menu.addAction(self.rename_icon,
-                                                    _('Rename %s')%display_name(tag),
-                            partial(self.context_menu_handler, action='edit_item',
-                                    index=index))
+                                                _('Rename %s')%display_name(tag),
+                                partial(self.context_menu_handler, action='edit_item_no_vl',
+                                        index=index))
                         if key in ('tags', 'series', 'publisher') or \
                                 self._model.db.field_metadata.is_custom_field(key):
+                            if self.model().get_in_vl():
+                                self.context_menu.addAction(self.delete_icon,
+                                                    _('Delete %s in virtual library')%display_name(tag),
+                                partial(self.context_menu_handler, action='delete_item_in_vl',
+                                    key=key, index=tag))
+
                             self.context_menu.addAction(self.delete_icon,
                                                     _('Delete %s')%display_name(tag),
-                                partial(self.context_menu_handler, action='delete_item',
+                                partial(self.context_menu_handler, action='delete_item_no_vl',
                                     key=key, index=tag))
                         if key == 'authors':
                             self.context_menu.addAction(_('Edit sort for %s')%display_name(tag),
@@ -455,7 +492,7 @@ class TagsView(QTreeView): # {{{
                         # to a user category'
                         m = self.context_menu.addMenu(self.user_category_icon,
                                         _('Add %s to user category')%display_name(tag))
-                        nt = self.model().category_node_tree
+                        nt = self.model().user_category_node_tree
                         def add_node_tree(tree_dict, m, path):
                             p = path[:]
                             for k in sorted(tree_dict.keys(), key=sort_key):
@@ -474,7 +511,7 @@ class TagsView(QTreeView): # {{{
                     elif key == 'search' and tag.is_searchable:
                         self.context_menu.addAction(self.rename_icon,
                                                     _('Rename %s')%display_name(tag),
-                            partial(self.context_menu_handler, action='edit_item',
+                            partial(self.context_menu_handler, action='edit_item_no_vl',
                                     index=index))
                         self.context_menu.addAction(self.delete_icon,
                                 _('Delete search %s')%display_name(tag),
@@ -482,11 +519,11 @@ class TagsView(QTreeView): # {{{
                                         action='delete_search', key=tag.original_name))
                     if key.startswith('@') and not item.is_gst:
                         self.context_menu.addAction(self.user_category_icon,
-                                _('Remove %(item)s from category %(cat)s')%
-                                            dict(item=display_name(tag), cat=item.py_name),
-                                partial(self.context_menu_handler,
-                                        action='delete_item_from_user_category',
-                                        key = key, index = tag_item))
+                            _('Remove %(item)s from category %(cat)s')%
+                            dict(item=display_name(tag), cat=item.py_name),
+                            partial(self.context_menu_handler,
+                                    action='delete_item_from_user_category',
+                                    key=key, index=tag_item))
                     if tag.is_searchable:
                         # Add the search for value items. All leaf nodes are searchable
                         self.context_menu.addAction(self.search_icon,
@@ -504,7 +541,7 @@ class TagsView(QTreeView): # {{{
                     if item.can_be_edited:
                         self.context_menu.addAction(self.rename_icon,
                             _('Rename %s')%item.py_name,
-                            partial(self.context_menu_handler, action='edit_item',
+                            partial(self.context_menu_handler, action='edit_item_no_vl',
                                     index=index))
                     self.context_menu.addAction(self.user_category_icon,
                             _('Add sub-category to %s')%item.py_name,
@@ -582,7 +619,6 @@ class TagsView(QTreeView): # {{{
             self.context_menu.addAction(_('Show all categories'),
                         partial(self.context_menu_handler, action='defaults'))
 
-
         m = self.context_menu.addMenu(_('Change sub-categorization scheme'))
         da = m.addAction(_('Disable'),
             partial(self.context_menu_handler, action='categorization', category='disable'))
@@ -609,10 +645,21 @@ class TagsView(QTreeView): # {{{
             da.setToolTip('*')
             pa.setToolTip('*')
 
+        if index.isValid() and self.model().rowCount(index) > 0:
+            self.context_menu.addSeparator()
+            self.context_menu.addAction(_('E&xpand all children'), partial(self.expand_node_and_descendants, index))
+
         if not self.context_menu.isEmpty():
             self.context_menu.popup(self.mapToGlobal(point))
         return True
 
+    def expand_node_and_descendants(self, index):
+        if not index.isValid():
+            return
+        self.expand(index)
+        for r in xrange(self.model().rowCount(index)):
+            self.expand_node_and_descendants(index.child(r, 0))
+
     def collapse_menu_hovered(self, action):
         tip = action.toolTip()
         if tip == '*':
@@ -626,7 +673,7 @@ class TagsView(QTreeView): # {{{
         if not index.isValid():
             return
         src_is_tb = event.mimeData().hasFormat('application/calibre+from_tag_browser')
-        item = index.data(Qt.UserRole).toPyObject()
+        item = index.data(Qt.UserRole)
         if item.type == TagTreeItem.ROOT:
             return
         flags = self._model.flags(index)
@@ -662,7 +709,7 @@ class TagsView(QTreeView): # {{{
             self.model().clear_state()
 
     def is_visible(self, idx):
-        item = idx.data(Qt.UserRole).toPyObject()
+        item = idx.data(Qt.UserRole)
         if getattr(item, 'type', None) == TagTreeItem.TAG:
             idx = idx.parent()
         return self.isExpanded(idx)
@@ -711,7 +758,7 @@ class TagsView(QTreeView): # {{{
 
     def show_item_at_index(self, idx, box=False,
                            position=QTreeView.PositionAtCenter):
-        if idx.isValid() and idx.data(Qt.UserRole).toPyObject() is not self._model.root_item:
+        if idx.isValid() and idx.data(Qt.UserRole) is not self._model.root_item:
             self.expand_parent(idx)
             self.setCurrentIndex(idx)
             self.scrollTo(idx, position)
@@ -725,5 +772,3 @@ class TagsView(QTreeView): # {{{
         self.setCurrentIndex(idx)
 
     # }}}
-
-
