@@ -10,10 +10,11 @@ __docformat__ = 'restructuredtext en'
 import json
 from base64 import b64encode
 
-from PyQt4.Qt import (QWidget, QGridLayout, QListWidget, QSize, Qt, QUrl,
+from PyQt5.Qt import (QWidget, QGridLayout, QListWidget, QSize, Qt, QUrl,
                       pyqtSlot, pyqtSignal, QVBoxLayout, QFrame, QLabel,
                       QLineEdit, QTimer, QPushButton, QIcon, QSplitter)
-from PyQt4.QtWebKit import QWebView, QWebPage, QWebElement
+from PyQt5.QtWebKitWidgets import QWebView, QWebPage
+from PyQt5.QtWebKit import QWebElement
 
 from calibre.ebooks.oeb.display.webview import load_html
 from calibre.gui2 import error_dialog, question_dialog, gprefs
@@ -87,16 +88,18 @@ class WebView(QWebView):  # {{{
 
     @property
     def scroll_frac(self):
-        val, ok = self.page().evaljs('window.pageYOffset/document.body.scrollHeight').toFloat()
-        if not ok:
+        try:
+            val = float(self.page().evaljs('window.pageYOffset/document.body.scrollHeight'))
+        except (TypeError, ValueError):
             val = 0
         return val
 # }}}
 
 class ItemEdit(QWidget):
 
-    def __init__(self, parent):
+    def __init__(self, parent, prefs=None):
         QWidget.__init__(self, parent)
+        self.prefs = prefs or gprefs
         self.setLayout(QVBoxLayout())
 
         self.la = la = QLabel('<b>'+_(
@@ -166,7 +169,7 @@ class ItemEdit(QWidget):
 
         l.addStretch()
 
-        state = gprefs.get('toc_edit_splitter_state', None)
+        state = self.prefs.get('toc_edit_splitter_state', None)
         if state is not None:
             sp.restoreState(state)
 
@@ -189,9 +192,9 @@ class ItemEdit(QWidget):
                     _('No match found for: %s')%text, show=True)
 
             delta = 1 if forwards else -1
-            current = unicode(d.currentItem().data(Qt.DisplayRole).toString())
+            current = unicode(d.currentItem().data(Qt.DisplayRole) or '')
             next_index = (d.currentRow() + delta)%d.count()
-            next = unicode(d.item(next_index).data(Qt.DisplayRole).toString())
+            next = unicode(d.item(next_index).data(Qt.DisplayRole) or '')
             msg = '<p>'+_('No matches for %(text)s found in the current file [%(current)s].'
                           ' Do you want to search in the %(which)s file [%(next)s]?')
             msg = msg%dict(text=text, current=current, next=next,
@@ -214,7 +217,8 @@ class ItemEdit(QWidget):
         self.dest_list.addItems(spine_names)
 
     def current_changed(self, item):
-        name = self.current_name = unicode(item.data(Qt.DisplayRole).toString())
+        name = self.current_name = unicode(item.data(Qt.DisplayRole) or '')
+        self.current_frag = None
         path = self.container.name_to_abspath(name)
         # Ensure encoding map is populated
         root = self.container.parsed(name)
@@ -247,13 +251,13 @@ class ItemEdit(QWidget):
         dest_index, frag = 0, None
         if item is not None:
             if where is None:
-                self.name.setText(item.data(0, Qt.DisplayRole).toString())
+                self.name.setText(item.data(0, Qt.DisplayRole) or '')
                 self.name.setCursorPosition(0)
-            toc = item.data(0, Qt.UserRole).toPyObject()
+            toc = item.data(0, Qt.UserRole)
             if toc.dest:
                 for i in xrange(self.dest_list.count()):
                     litem = self.dest_list.item(i)
-                    if unicode(litem.data(Qt.DisplayRole).toString()) == toc.dest:
+                    if unicode(litem.data(Qt.DisplayRole) or '') == toc.dest:
                         dest_index = i
                         frag = toc.frag
                         break
@@ -302,5 +306,3 @@ class ItemEdit(QWidget):
     def result(self):
         return (self.current_item, self.current_where, self.current_name,
                 self.current_frag, unicode(self.name.text()))
-
-
