@@ -6,18 +6,21 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
-from PyQt4.Qt import QTextCharFormat
+from PyQt5.Qt import QTextCharFormat
 
 from calibre.ebooks.oeb.base import OEB_DOCS, OEB_STYLES
 from calibre.ebooks.oeb.polish.container import guess_type
 
 _xml_types = {'application/oebps-page-map+xml', 'application/vnd.adobe-page-template+xml', 'application/page-template+xml'} | {
             guess_type('a.'+x) for x in ('ncx', 'opf', 'svg', 'xpgt', 'xml')}
+_js_types = {'application/javascript', 'application/x-javascript'}
 
 def syntax_from_mime(name, mime):
     for syntax, types in (('html', OEB_DOCS), ('css', OEB_STYLES), ('xml', _xml_types)):
         if mime in types:
             return syntax
+    if mime in _js_types:
+        return 'javascript'
     if mime.startswith('text/'):
         return 'text'
     if mime.startswith('image/') and mime.partition('/')[-1].lower() in {
@@ -26,8 +29,10 @@ def syntax_from_mime(name, mime):
     if mime.endswith('+xml'):
         return 'xml'
 
+all_text_syntaxes = frozenset({'text', 'html', 'xml', 'css', 'javascript'})
+
 def editor_from_syntax(syntax, parent=None):
-    if syntax in {'text', 'html', 'css', 'xml'}:
+    if syntax in all_text_syntaxes:
         from calibre.gui2.tweak_book.editor.widget import Editor
         return Editor(syntax, parent=parent)
     elif syntax == 'raster_image':
