@@ -159,6 +159,7 @@ class Editor(QMainWindow):
             return self.get_raw_data()
         def fset(self, val):
             self.canvas.load_image(val)
+            self._is_modified = False  # The image_changed signal will have been triggered causing this editor to be incorrectly marked as modified
         return property(fget=fget, fset=fset)
 
     def replace_data(self, raw, only_if_different=True):
@@ -272,6 +273,8 @@ class Editor(QMainWindow):
         m.addAction(_('Sharpen image'), self.sharpen_image)
         m.addAction(_('Blur image'), self.blur_image)
         m.addAction(_('De-speckle image'), self.canvas.despeckle_image)
+        m.addAction(_('Improve contrast (normalize image)'), self.canvas.normalize_image)
+        m.addAction(_('Make image look like an oil painting'), self.oilify_image)
 
         self.info_bar = b = self.addToolBar(_('Image information bar'))
         b.setObjectName('image_info_bar')
@@ -320,6 +323,12 @@ class Editor(QMainWindow):
         if ok:
             self.canvas.blur_image(sigma=val)
 
+    def oilify_image(self):
+        val, ok = QInputDialog.getDouble(self, _('Oilify image'), _(
+            'The strength of the operation (higher numbers have larger effects)'), value=4, min=0.1, max=20)
+        if ok:
+            self.canvas.oilify_image(radius=val)
+
 def launch_editor(path_to_edit, path_is_raw=False):
     app = QApplication([])
     if path_is_raw:
