@@ -9,7 +9,7 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 import sys
 from collections import defaultdict, deque
 
-from PyQt4.Qt import (
+from PyQt5.Qt import (
     QTextCursor, pyqtSlot, QTextBlockUserData, QTextLayout, QTimer)
 
 from ..themes import highlight_to_char_format
@@ -228,7 +228,7 @@ class SyntaxHighlighter(object):
     def apply_format_changes(self, block, formats):
         layout = block.layout()
         preedit_start = layout.preeditAreaPosition()
-        preedit_length = layout.preeditAreaText().length()
+        preedit_length = len(layout.preeditAreaText())
         if preedit_length != 0 and preedit_start != 0:
             for r in formats:
                 # Adjust range by pre-edit text, if any
