@@ -368,6 +368,40 @@ class TextEdit(PlainTextEdit):
             self.saved_matches[save_match] = (pat, m)
         return True
 
+    def find_text(self, pat, wrap=False, complete=False):
+        reverse = pat.flags & regex.REVERSE
+        c = self.textCursor()
+        c.clearSelection()
+        if complete:
+            # Search the entire text
+            c.movePosition(c.End if reverse else c.Start)
+        pos = c.Start if reverse else c.End
+        if wrap and not complete:
+            pos = c.End if reverse else c.Start
+        c.movePosition(pos, c.KeepAnchor)
+        if hasattr(self.smarts, 'find_text'):
+            self.highlighter.join()
+            found, start, end = self.smarts.find_text(pat, c)
+            if not found:
+                return False
+        else:
+            raw = unicode(c.selectedText()).replace(PARAGRAPH_SEPARATOR, '\n').rstrip('\0')
+            m = pat.search(raw)
+            if m is None:
+                return False
+            start, end = m.span()
+            if start == end:
+                return False
+        if reverse:
+            start, end = end, start
+        c.clearSelection()
+        c.setPosition(start)
+        c.setPosition(end, c.KeepAnchor)
+        self.setTextCursor(c)
+        # Center search result on screen
+        self.centerCursor()
+        return True
+
     def find_spell_word(self, original_words, lang, from_cursor=True, center_on_cursor=True):
         c = self.textCursor()
         c.setPosition(c.position())
@@ -391,10 +425,13 @@ class TextEdit(PlainTextEdit):
             c.setPosition(c.anchor() + idx)
             c.setPosition(c.position() + string_length(word), c.KeepAnchor)
             if self.smarts.verify_for_spellcheck(c, self.highlighter):
-                self.setTextCursor(c)
-                if center_on_cursor:
-                    self.centerCursor()
-                return True
+                self.highlighter.join()  # Ensure highlighting is finished
+                locale = self.spellcheck_locale_for_cursor(c)
+                if not lang or not locale or (locale and lang == locale.langcode):
+                    self.setTextCursor(c)
+                    if center_on_cursor:
+                        self.centerCursor()
+                    return True
             c.setPosition(c.position())
             c.movePosition(c.End, c.KeepAnchor)
 
@@ -563,7 +600,7 @@ class TextEdit(PlainTextEdit):
             formats = self.highlighter.parse_single_block(c.block())[0]
         pos = c.positionInBlock()
         for r in formats:
-            if r.start <= pos < r.start + r.length and r.format.property(SPELL_PROPERTY):
+            if r.start <= pos <= r.start + r.length and r.format.property(SPELL_PROPERTY):
                 return r.format.property(SPELL_LOCALE_PROPERTY)
 
     def recheck_word(self, word, locale):
@@ -583,7 +620,7 @@ class TextEdit(PlainTextEdit):
             return
         pos = cursor.positionInBlock()
         for r in cursor.block().layout().additionalFormats():
-            if r.start <= pos < r.start + r.length and r.format.property(SYNTAX_PROPERTY):
+            if r.start <= pos <= r.start + r.length and r.format.property(SYNTAX_PROPERTY):
                 return r
 
     def syntax_format_for_cursor(self, cursor):
