@@ -286,6 +286,9 @@ class Editor(QMainWindow):
     def find(self, *args, **kwargs):
         return self.editor.find(*args, **kwargs)
 
+    def find_text(self, *args, **kwargs):
+        return self.editor.find_text(*args, **kwargs)
+
     def find_spell_word(self, *args, **kwargs):
         return self.editor.find_spell_word(*args, **kwargs)
 
@@ -561,7 +564,7 @@ class Editor(QMainWindow):
             m.addMenu(cm)
         if self.syntax == 'html':
             m.addAction(actions['multisplit'])
-        m.exec_(self.editor.mapToGlobal(pos))
+        m.exec_(self.editor.viewport().mapToGlobal(pos))
 
     def goto_sourceline(self, *args, **kwargs):
         return self.editor.goto_sourceline(*args, **kwargs)
