@@ -166,6 +166,7 @@ class FileList(QTreeWidget):
 
     def __init__(self, parent=None):
         QTreeWidget.__init__(self, parent)
+        self.categories = {}
         self.ordered_selected_indexes = False
         pi = plugins['progress_indicator'][0]
         if hasattr(pi, 'set_no_activate_on_click'):
@@ -260,6 +261,8 @@ class FileList(QTreeWidget):
         self.current_edited_name = None
 
     def build(self, container, preserve_state=True):
+        if container is None:
+            return
         if preserve_state:
             state = self.get_state()
         self.clear()
@@ -304,17 +307,21 @@ class FileList(QTreeWidget):
             return category
 
         def set_display_name(name, item):
-            if name in processed:
-                # We have an exact duplicate (can happen if there are
-                # duplicates in the spine)
-                item.setText(0, processed[name].text(0))
-                item.setText(1, processed[name].text(1))
-                return
+            if tprefs['file_list_shows_full_pathname']:
+                text = name
+            else:
+                if name in processed:
+                    # We have an exact duplicate (can happen if there are
+                    # duplicates in the spine)
+                    item.setText(0, processed[name].text(0))
+                    item.setText(1, processed[name].text(1))
+                    return
+
+                parts = name.split('/')
+                text = parts.pop()
+                while text in seen and parts:
+                    text = parts.pop() + '/' + text
 
-            parts = name.split('/')
-            text = parts[-1]
-            while text in seen and parts:
-                text = parts.pop() + '/' + text
             seen[text] = item
             item.setText(0, text)
             item.setText(1, hexlify(sort_key(text)))
@@ -348,6 +355,7 @@ class FileList(QTreeWidget):
 
         cannot_be_renamed = container.names_that_must_not_be_changed
         ncx_mime = guess_type('a.ncx')
+        nav_items = frozenset(container.manifest_items_with_property('nav'))
 
         def create_item(name, linear=None):
             imt = container.mime_map.get(name, guess_type(name))
@@ -374,7 +382,7 @@ class FileList(QTreeWidget):
             if name in container.opf_name:
                 emblems.append('metadata.png')
                 tooltips.append(_('This file contains all the metadata and book structure information'))
-            if imt == ncx_mime:
+            if imt == ncx_mime or name in nav_items:
                 emblems.append('toc.png')
                 tooltips.append(_('This file contains the metadata table of contents'))
             if name not in manifested_names and not container.ok_to_be_unmanifested(name):
