@@ -321,6 +321,14 @@ class MainWindowSettings(BasicSettings):
         ))
         l.addRow(nd)
 
+        nd = self('file_list_shows_full_pathname')
+        nd.setText(_('Show full file paths in the Files Browser'))
+        nd.setToolTip('<p>' + _(
+            'Showing the full file paths is useful when editing books that contain'
+            ' multiple files with the same file name.'
+        ))
+        l.addRow(nd)
+
 class PreviewSettings(BasicSettings):
 
     def __init__(self, parent=None):
