@@ -10,21 +10,31 @@ import shutil, os, errno
 from threading import Thread
 from Queue import LifoQueue, Empty
 
-from PyQt4.Qt import (QObject, pyqtSignal, QLabel, QWidget, QHBoxLayout, Qt)
+from PyQt5.Qt import (QObject, pyqtSignal, QLabel, QWidget, QHBoxLayout, Qt)
 
 from calibre.constants import iswindows
 from calibre.ptempfile import PersistentTemporaryFile
 from calibre.gui2.progress_indicator import ProgressIndicator
 from calibre.utils import join_with_timeout
-from calibre.utils.filenames import atomic_rename
+from calibre.utils.filenames import atomic_rename, format_permissions
 from calibre.utils.ipc import RC
 
+def save_dir_container(container, path):
+    if not os.path.exists(path):
+        os.makedirs(path)
+    if not os.path.isdir(path):
+        raise ValueError('%s is not a folder, cannot save a directory based container to it' % path)
+    container.commit(path)
+
 def save_container(container, path):
+    if container.is_dir:
+        return save_dir_container(container, path)
     temp = PersistentTemporaryFile(
         prefix=('_' if iswindows else '.'), suffix=os.path.splitext(path)[1], dir=os.path.dirname(path))
     if hasattr(os, 'fchmod'):
         # Ensure file permissions and owner information is preserved
         fno = temp.fileno()
+        st = None
         try:
             st = os.stat(path)
         except EnvironmentError as err:
@@ -32,16 +42,28 @@ def save_container(container, path):
                 raise
             # path may not exist if we are saving a copy, in which case we use
             # the metadata from the original book
-            st = os.stat(container.path_to_ebook)
-        os.fchmod(fno, st.st_mode)
-        try:
-            os.fchown(fno, st.st_uid, st.st_gid)
-        except EnvironmentError as err:
-            if err.errno != errno.EPERM:
-                # ignore chown failure as user could be editing file belonging
-                # to a different user, in which case we really cant do anything
-                # about it short of making the file update non-atomic
-                raise
+            try:
+                st = os.stat(container.path_to_ebook)
+            except EnvironmentError as err:
+                if err.errno != errno.ENOENT:
+                    raise
+                # Somebody deleted the original file
+        if st is not None:
+            try:
+                os.fchmod(fno, st.st_mode)
+            except EnvironmentError as err:
+                if err.errno != errno.EPERM:
+                    raise
+                raise EnvironmentError('Failed to change permissions of %s to %s (%s), with error: %s. Most likely the %s directory has a restrictive umask' % (
+                    temp.name, oct(st.st_mode), format_permissions(st.st_mode), errno.errorcode[err.errno], os.path.dirname(temp.name)))
+            try:
+                os.fchown(fno, st.st_uid, st.st_gid)
+            except EnvironmentError as err:
+                if err.errno not in (errno.EPERM, errno.EACCES):
+                    # ignore chown failure as user could be editing file belonging
+                    # to a different user, in which case we really cant do anything
+                    # about it short of making the file update non-atomic
+                    raise
 
     temp.close()
     temp = temp.name
@@ -99,6 +121,7 @@ class SaveManager(QObject):
     start_save = pyqtSignal()
     report_error = pyqtSignal(object)
     save_done = pyqtSignal()
+    check_for_completion = pyqtSignal()
 
     def __init__(self, parent, notify=None):
         QObject.__init__(self, parent)
@@ -128,14 +151,17 @@ class SaveManager(QObject):
                 self.requests.task_done()
                 self.__empty_queue()
                 break
+            error_occurred = True
             try:
                 count, tdir, container = x
-                self.process_save(count, tdir, container)
+                error_occurred = self.process_save(count, tdir, container)
             except:
                 import traceback
                 traceback.print_exc()
             finally:
                 self.requests.task_done()
+            if not error_occurred:
+                self.check_for_completion.emit()
 
     def notify_calibre(self):
         while True:
@@ -162,14 +188,17 @@ class SaveManager(QObject):
             return
         self.last_saved = count
         self.start_save.emit()
+        error_occurred = False
         try:
             self.do_save(tdir, container)
         except:
             import traceback
             self.report_error.emit(traceback.format_exc())
+            error_occurred = True
         self.save_done.emit()
         if self.notify_data:
             self.notify_requests.put(True)
+        return error_occurred
 
     def do_save(self, tdir, container):
         try:
