@@ -316,6 +316,7 @@ class ManageUserDictionaries(Dialog):
         l.addRow(bb)
         if d.exec_() != d.Accepted:
             return
+        d.loc.update_recently_used()
         word = unicode(w.text())
         lang = (loc.lang_codes or [canonicalize_lang(get_lang())])[0]
         if not word:
@@ -360,7 +361,7 @@ class ManageUserDictionaries(Dialog):
         words = set(filter(None, [x.strip() for x in unicode(w.toPlainText()).splitlines()]))
         lang = lc[0]
         words = {(w, lang) for w in words} - self.current_dictionary.words
-        if dictionaries.add_to_user_dictionary(self.current_dictionary.name, words, None):
+        if dictionaries.add_to_user_dictionary(self.current_dictionary.name, words, DictionaryLocale(lang, None)):
             dictionaries.clear_caches()
             self.show_current_dictionary()
             self.dictionaries_changed = True
@@ -969,7 +970,7 @@ class SpellCheck(Dialog):
         self.user_dictionaries_missing_label = la = QLabel(_(
             'You have no active user dictionaries. You must'
             ' choose at least one active user dictionary via'
-            ' Preferences->Editor->Manage spelling dictionaries'))
+            ' Preferences->Editor->Manage spelling dictionaries'), self)
         la.setWordWrap(True)
         self.initialize_user_dictionaries()
         d.setMinimumContentsLength(25)
