@@ -36,6 +36,7 @@ from calibre.gui2.tweak_book.check import Check
 from calibre.gui2.tweak_book.check_links import CheckExternalLinks
 from calibre.gui2.tweak_book.spell import SpellCheck
 from calibre.gui2.tweak_book.search import SavedSearches
+from calibre.gui2.tweak_book.text_search import TextSearch
 from calibre.gui2.tweak_book.toc import TOCViewer
 from calibre.gui2.tweak_book.char_select import CharSelect
 from calibre.gui2.tweak_book.live_css import LiveCSS
@@ -48,7 +49,7 @@ from calibre.utils.icu import character_name, sort_key
 from calibre.utils.localization import localize_user_manual_link
 
 def open_donate():
-    open_url(QUrl('http://calibre-ebook.com/donate'))
+    open_url(QUrl('https://calibre-ebook.com/donate'))
 
 class Central(QStackedWidget):  # {{{
 
@@ -248,6 +249,7 @@ class Main(MainWindow):
         self.check_book = Check(self)
         self.spell_check = SpellCheck(parent=self)
         self.toc_view = TOCViewer(self)
+        self.text_search = TextSearch(self)
         self.saved_searches = SavedSearches(self)
         self.image_browser = InsertImage(self, for_browsing=True)
         self.reports = Reports(self)
@@ -392,6 +394,8 @@ class Main(MainWindow):
             'Check external links in the book'))
         self.action_compress_images = treg('compress-image.png', _('Compress &images losslessly'), self.boss.compress_images, 'compress-images', (), _(
             'Compress images losslessly'))
+        self.action_transform_styles = treg('wizard.png', _('Transform &styles'), self.boss.transform_styles, 'transform-styles', (), _(
+            'Transform styles used in the book'))
 
         def ereg(icon, text, target, sid, keys, description):
             return reg(icon, text, partial(self.boss.editor_action, target), sid, keys, description)
@@ -448,6 +452,8 @@ class Main(MainWindow):
         self.action_go_to_line = reg(None, _('Go to &line'), self.boss.go_to_line_number, 'go-to-line-number', ('Ctrl+.',), _('Go to line number'))
         self.action_saved_searches = treg('folder_saved_search.png', _('Sa&ved searches'),
                                           self.boss.saved_searches, 'saved-searches', (), _('Show the saved searches dialog'))
+        self.action_text_search = treg('view.png', _('Search ignoring HTML markup'),
+                                          self.boss.show_text_search, 'text-search', (), _('Show the text search panel'))
 
         # Check Book actions
         group = _('Check Book')
@@ -474,7 +480,7 @@ class Main(MainWindow):
                 'Close all tabs except the current tab'))
         self.action_help = treg(
             'help.png', _('User &Manual'), lambda : open_url(QUrl(localize_user_manual_link(
-                'http://manual.calibre-ebook.com/edit.html'))), 'user-manual', 'F1', _(
+                'https://manual.calibre-ebook.com/edit.html'))), 'user-manual', 'F1', _(
                 'Show User Manual'))
         self.action_browse_images = treg(
             'view-image.png', _('&Browse images in book'), self.boss.browse_images, 'browse-images', (), _(
@@ -543,6 +549,7 @@ class Main(MainWindow):
         e.addAction(self.action_compress_images)
         e.addAction(self.action_smarten_punctuation)
         e.addAction(self.action_remove_unused_css)
+        e.addAction(self.action_transform_styles)
         e.addAction(self.action_fix_html_all)
         e.addAction(self.action_pretty_all)
         e.addAction(self.action_rationalize_folders)
@@ -588,6 +595,8 @@ class Main(MainWindow):
         e.addSeparator()
         a(self.action_saved_searches)
         e.aboutToShow.connect(self.search_menu_about_to_show)
+        e.addSeparator()
+        a(self.action_text_search)
 
         if self.plugin_menu_actions:
             e = b.addMenu(_('&Plugins'))
@@ -707,6 +716,12 @@ class Main(MainWindow):
         self.addDockWidget(Qt.LeftDockWidgetArea, d)
         d.close()  # Hidden by default
 
+        d = create(_('Text Search'), 'text-search')
+        d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.BottomDockWidgetArea | Qt.TopDockWidgetArea)
+        d.setWidget(self.text_search)
+        self.addDockWidget(Qt.LeftDockWidgetArea, d)
+        d.close()  # Hidden by default
+
         d = create(_('Checkpoints'), 'checkpoints')
         d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea | Qt.BottomDockWidgetArea | Qt.TopDockWidgetArea)
         self.checkpoints = CheckpointView(self.boss.global_undo, parent=d)
@@ -740,6 +755,7 @@ class Main(MainWindow):
         self.central.save_state()
         self.saved_searches.save_state()
         self.check_book.save_state()
+        self.text_search.save_state()
 
     def restore_state(self):
         geom = tprefs.get('main_window_geometry', None)
