@@ -276,7 +276,6 @@ class Main(MainWindow):
         d.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea)
 
         self.footnotes_dock = d = QDockWidget(_('Footnotes'), self)
-        d.visibilityChanged.connect(self.footnote_visibility_changed)
         d.setContextMenuPolicy(Qt.CustomContextMenu)
         self.footnotes_view = FootnotesView(self)
         self.footnotes_view.follow_link.connect(self.view.follow_footnote_link)
@@ -388,7 +387,7 @@ class Main(MainWindow):
         a('copy', _('Copy to clipboard'), 'edit-copy.png').setDisabled(True)
         a('font_size_larger', _('Increase font size'), 'font_size_larger.png')
         a('font_size_smaller', _('Decrease font size'), 'font_size_smaller.png')
-        a('table_of_contents', self.toc_dock, 'highlight_only_on.png', sc_name='Table of Contents')
+        a('table_of_contents', self.toc_dock, 'toc.png', sc_name='Table of Contents')
         a('full_screen', _('Toggle full screen'), 'page.png', sc_name='Fullscreen').setCheckable(True)
         self.tool_bar.addSeparator()
 
@@ -401,7 +400,7 @@ class Main(MainWindow):
         self.tool_bar.addSeparator()
 
         a('preferences', _('Preferences'), 'config.png')
-        a('metadata', _('Show book metadata'), 'dialog_information.png').setCheckable(True)
+        a('metadata', _('Show book metadata'), 'metadata.png').setCheckable(True)
         a('load_theme', _('Load a theme'), 'wizard.png', menu_name='themes', popup_mode=QToolButton.InstantPopup)
         self.tool_bar.addSeparator()
 
