@@ -6,21 +6,24 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2014, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import os, glob, shutil, re
-from collections import namedtuple
+import os, glob, shutil, re, sys
+from collections import namedtuple, defaultdict
 from operator import attrgetter
 from itertools import chain
+from functools import partial
 
+from calibre import prints
 from calibre.constants import plugins, config_dir
 from calibre.spell import parse_lang_code
 from calibre.utils.config import JSONConfig
+from calibre.utils.icu import capitalize
 from calibre.utils.localization import get_lang, get_system_locale
 
 Dictionary = namedtuple('Dictionary', 'primary_locale locales dicpath affpath builtin name id')
 LoadedDictionary = namedtuple('Dictionary', 'primary_locale locales obj builtin name id')
 hunspell = plugins['hunspell'][0]
 if hunspell is None:
-    raise RuntimeError('Failed to load hunspell: %s' % plugins[1])
+    raise RuntimeError('Failed to load hunspell: %s' % plugins['hunspell'][1])
 dprefs = JSONConfig('dictionaries/prefs.json')
 dprefs.defaults['preferred_dictionaries'] = {}
 dprefs.defaults['preferred_locales'] = {}
@@ -150,17 +153,23 @@ def get_dictionary(locale, exact_match=False):
                 return d
 
 def load_dictionary(dictionary):
+    from calibre.spell.import_from import convert_to_utf8
     with open(dictionary.dicpath, 'rb') as dic, open(dictionary.affpath, 'rb') as aff:
-        obj = hunspell.Dictionary(dic.read(), aff.read())
+        dic_data, aff_data = dic.read(), aff.read()
+        dic_data, aff_data = convert_to_utf8(dic_data, aff_data)
+        obj = hunspell.Dictionary(dic_data, aff_data)
     return LoadedDictionary(dictionary.primary_locale, dictionary.locales, obj, dictionary.builtin, dictionary.name, dictionary.id)
 
 class Dictionaries(object):
 
     def __init__(self):
         self.remove_hyphenation = re.compile('[\u2010-]+')
+        self.negative_pat = re.compile('-[.\d+]')
+        self.fix_punctuation_pat = re.compile(r'''[:.]''')
         self.dictionaries = {}
         self.word_cache = {}
         self.ignored_words = set()
+        self.added_user_words = {}
         try:
             self.default_locale = parse_lang_code(get_lang())
         except ValueError:
@@ -183,6 +192,14 @@ class Dictionaries(object):
             ans = get_dictionary(locale)
             if ans is not None:
                 ans = load_dictionary(ans)
+                for ud in self.active_user_dictionaries:
+                    for word, langcode in ud.words:
+                        if langcode == locale.langcode:
+                            try:
+                                ans.obj.add(word)
+                            except Exception:
+                                # not critical since all it means is that the word wont show up in suggestions
+                                prints('Failed to add the word %r to the dictionary for %s' % (word, locale), file=sys.stderr)
             self.dictionaries[locale] = ans
         return ans
 
@@ -224,6 +241,18 @@ class Dictionaries(object):
     def save_user_dictionaries(self):
         dprefs['user_dictionaries'] = [d.serialize() for d in self.all_user_dictionaries]
 
+    def add_user_words(self, words, langcode):
+        for d in self.dictionaries.itervalues():
+            if d and getattr(d.primary_locale, 'langcode', None) == langcode:
+                for word in words:
+                    d.obj.add(word)
+
+    def remove_user_words(self, words, langcode):
+        for d in self.dictionaries.itervalues():
+            if d and d.primary_locale.langcode == langcode:
+                for word in words:
+                    d.obj.remove(word)
+
     def add_to_user_dictionary(self, name, word, locale):
         ud = self.user_dictionary(name)
         if ud is None:
@@ -231,8 +260,10 @@ class Dictionaries(object):
         wl = len(ud.words)
         if isinstance(word, (set, frozenset)):
             ud.words |= word
+            self.add_user_words(word, locale.langcode)
         else:
             ud.words.add((word, locale.langcode))
+            self.add_user_words((word,), locale.langcode)
         if len(ud.words) > wl:
             self.save_user_dictionaries()
             try:
@@ -252,21 +283,26 @@ class Dictionaries(object):
         if changed:
             self.word_cache.pop((word, locale), None)
             self.save_user_dictionaries()
+            self.remove_user_words((word,), locale.langcode)
         return changed
 
     def remove_from_user_dictionary(self, name, words):
         changed = False
+        removals = defaultdict(set)
         keys = [(w, l.langcode) for w, l in words]
         for d in self.all_user_dictionaries:
             if d.name == name:
                 for key in keys:
                     if key in d.words:
                         d.words.discard(key)
+                        removals[key[1]].add(key[0])
                         changed = True
         if changed:
             for key in words:
                 self.word_cache.pop(key, None)
-                self.save_user_dictionaries()
+            for langcode, words in removals.iteritems():
+                self.remove_user_words(words, langcode)
+            self.save_user_dictionaries()
         return changed
 
     def word_in_user_dictionary(self, word, locale):
@@ -327,6 +363,8 @@ class Dictionaries(object):
                             pass
                     else:
                         ans = True
+            if ans is False and self.negative_pat.match(word) is not None:
+                ans = True
             self.word_cache[key] = ans
         return ans
 
@@ -334,6 +372,10 @@ class Dictionaries(object):
         locale = locale or self.default_locale
         d = self.dictionary_for_locale(locale)
         ans = ()
+
+        def add_suggestion(w, ans):
+            return (w,) + tuple(x for x in ans if x != w)
+
         if d is not None:
             try:
                 ans = d.obj.suggest(unicode(word))
@@ -343,11 +385,34 @@ class Dictionaries(object):
                 dehyphenated_word = self.remove_hyphenation.sub('', word)
                 if len(dehyphenated_word) != len(word) and self.recognized(dehyphenated_word, locale):
                     # Ensure the de-hyphenated word is present and is the first suggestion
-                    ans = (dehyphenated_word,) + tuple(x for x in ans if x != dehyphenated_word)
+                    ans = add_suggestion(dehyphenated_word, ans)
+                else:
+                    m = self.fix_punctuation_pat.search(word)
+                    if m is not None:
+                        w1, w2 = word[:m.start()], word[m.end():]
+                        if self.recognized(w1) and self.recognized(w2):
+                            fw = w1 + m.group() + ' ' + w2
+                            ans = add_suggestion(fw, ans)
+                            if capitalize(w2) != w2:
+                                fw = w1 + m.group() + ' ' + capitalize(w2)
+                                ans = add_suggestion(fw, ans)
+
         return ans
 
-if __name__ == '__main__':
+def test_dictionaries():
     dictionaries = Dictionaries()
     dictionaries.initialize()
-    print (dictionaries.recognized('recognized', parse_lang_code('en')))
-    print (dictionaries.suggestions('ade-quately', parse_lang_code('en')))
+    eng = parse_lang_code('en')
+    rec = partial(dictionaries.recognized, locale=eng)
+    sg = partial(dictionaries.suggestions, locale=eng)
+    if not rec('recognized'):
+        raise ValueError('recognized not recognized')
+    if 'adequately' not in sg('ade-quately'):
+        raise ValueError('adequately not in %s' % sg('ade-quately'))
+    if 'magic. Wand' not in sg('magic.wand'):
+        raise ValueError('magic. Wand not in: %s' % sg('magic.wand'))
+    d = load_dictionary(get_dictionary(parse_lang_code('es'))).obj
+    assert d.recognized('Achí')
+
+if __name__ == '__main__':
+    test_dictionaries()
