@@ -18,7 +18,7 @@ from calibre.ebooks.metadata.book.json_codec import JsonCodec
 from calibre.srv.errors import HTTPNotFound
 from calibre.srv.routes import endpoint, json
 from calibre.srv.content import get as get_content, icon as get_icon
-from calibre.srv.utils import http_date, custom_fields_to_display, encode_name, decode_name
+from calibre.srv.utils import http_date, custom_fields_to_display, encode_name, decode_name, get_db
 from calibre.utils.config import prefs, tweaks
 from calibre.utils.date import isoformat, timestampfromdt
 from calibre.utils.icu import numeric_sort_key as sort_key
@@ -39,12 +39,6 @@ def get_pagination(query, num=100, offset=0):
         raise HTTPNotFound("Invalid offset")
     return num, offset
 
-def get_db(ctx, library_id):
-    db = ctx.get_library(library_id)
-    if db is None:
-        raise HTTPNotFound('Library %r not found' % library_id)
-    return db
-
 def category_icon(category, meta):  # {{{
     if category in category_icon_map:
         icon = category_icon_map[category]
@@ -156,7 +150,7 @@ def book(ctx, rd, book_id, library_id):
 
     If id_is_uuid is true then the book_id is assumed to be a book uuid instead.
     '''
-    db = get_db(ctx, library_id)
+    db = get_db(ctx, rd, library_id)
     with db.safe_read_lock:
         id_is_uuid = rd.query.get('id_is_uuid', 'false')
         oid = book_id
@@ -195,7 +189,7 @@ def books(ctx, rd, library_id):
 
     If id_is_uuid is true then the book_id is assumed to be a book uuid instead.
     '''
-    db = get_db(ctx, library_id)
+    db = get_db(ctx, rd, library_id)
     with db.safe_read_lock:
         id_is_uuid = rd.query.get('id_is_uuid', 'false')
         ids = rd.query.get('ids')
@@ -246,7 +240,7 @@ def categories(ctx, rd, library_id):
         }
 
     '''
-    db = get_db(ctx, library_id)
+    db = get_db(ctx, rd, library_id)
     with db.safe_read_lock:
         ans = {}
         categories = ctx.get_categories(rd, db)
@@ -334,10 +328,10 @@ def category(ctx, rd, encoded_name, library_id):
     :param sort_order: asc or desc
 
     To learn how to create subcategories see
-    http://manual.calibre-ebook.com/sub_groups.html
+    https://manual.calibre-ebook.com/sub_groups.html
     '''
 
-    db = get_db(ctx, library_id)
+    db = get_db(ctx, rd, library_id)
     with db.safe_read_lock:
         num, offset = get_pagination(rd.query)
         sort, sort_order = rd.query.get('sort'), rd.query.get('sort_order')
@@ -467,7 +461,7 @@ def books_in(ctx, rd, encoded_category, encoded_item, library_id):
 
     Optional: ?num=100&offset=0&sort=title&sort_order=asc&get_additional_fields=
     '''
-    db = get_db(ctx, library_id)
+    db = get_db(ctx, rd, library_id)
     with db.safe_read_lock:
         try:
             dname, ditem = map(decode_name, (encoded_category, encoded_item))
@@ -553,11 +547,16 @@ def search(ctx, rd, library_id):
 
     Optional: ?num=100&offset=0&sort=title&sort_order=asc&query=
     '''
-    db = get_db(ctx, library_id)
+    db = get_db(ctx, rd, library_id)
     query = rd.query.get('query')
     num, offset = get_pagination(rd.query)
     with db.safe_read_lock:
         return search_result(ctx, rd, db, query, num, offset, rd.query.get('sort', 'title'), rd.query.get('sort_order', 'asc'))
+
 # }}}
 
-
+@endpoint('/ajax/library-info', postprocess=json)
+def library_info(ctx, rd):
+    ' Return info about available libraries '
+    library_map, default_library = ctx.library_info(rd)
+    return {'library_map':library_map, 'default_library':default_library}
