@@ -36,7 +36,7 @@ class LibraryBroker(object):
             seen.add(path)
             if not LibraryDatabase.exists_at(path):
                 continue
-            bname = library_id = force_unicode(os.path.basename(path), filesystem_encoding)
+            bname = library_id = force_unicode(os.path.basename(path), filesystem_encoding).replace(' ', '_')
             c = 0
             while library_id in self.lmap:
                 c += 1
@@ -80,6 +80,7 @@ class Context(object):
 
     log = None
     url_for = None
+    jobs_manager = None
     CATEGORY_CACHE_SIZE = 25
     SEARCH_CACHE_SIZE = 100
 
@@ -89,6 +90,19 @@ class Context(object):
         self.testing = testing
         self.lock = Lock()
         self.user_manager = UserManager(opts.userdb)
+        self.ignored_fields = frozenset(filter(None, (x.strip() for x in (opts.ignored_fields or '').split(','))))
+        self.displayed_fields = frozenset(filter(None, (x.strip() for x in (opts.displayed_fields or '').split(','))))
+
+    def start_job(self, name, module, func, args=(), kwargs=None, job_done_callback=None, job_data=None):
+        return self.jobs_manager.start_job(name, module, func, args, kwargs, job_done_callback, job_data)
+
+    def job_status(self, job_id):
+        return self.jobs_manager.job_status(job_id)
+
+    def is_field_displayable(self, field):
+        if self.displayed_fields and field not in self.displayed_fields:
+            return False
+        return field not in self.ignored_fields
 
     def init_session(self, endpoint, data):
         pass
@@ -96,11 +110,12 @@ class Context(object):
     def finalize_session(self, endpoint, data, output):
         pass
 
-    def get_library(self, library_id=None):
+    def get_library(self, data, library_id=None):
+        # TODO: Restrict the libraries based on data.username
         return self.library_broker.get(library_id)
 
-    @property
-    def library_map(self):
+    def library_info(self, data):
+        # TODO: Restrict the libraries based on data.username
         return self.library_broker.library_map, self.library_broker.default_library
 
     def allowed_book_ids(self, data, db):
@@ -173,7 +188,7 @@ class Handler(object):
             prefer_basic_auth = {'auto':has_ssl, 'basic':True}.get(opts.auth_mode, 'digest')
             self.auth_controller = AuthController(user_credentials=ctx.user_manager, prefer_basic_auth=prefer_basic_auth)
         self.router = Router(ctx=ctx, url_prefix=opts.url_prefix, auth_controller=self.auth_controller)
-        for module in ('content', 'ajax', 'code'):
+        for module in ('content', 'ajax', 'code', 'legacy', 'opds', 'books'):
             module = import_module('calibre.srv.' + module)
             self.router.load_routes(vars(module).itervalues())
         self.router.finalize()
@@ -185,6 +200,9 @@ class Handler(object):
         if self.auth_controller is not None:
             self.auth_controller.log = log
 
+    def set_jobs_manager(self, jobs_manager):
+        self.router.ctx.jobs_manager = jobs_manager
+
     def close(self):
         self.router.ctx.library_broker.close()
 
