@@ -6,7 +6,7 @@ from __future__ import (unicode_literals, division, absolute_import,
 __license__ = 'GPL v3'
 __copyright__ = '2015, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import os, httplib, hashlib, uuid, time, struct, repr as reprlib
+import os, httplib, hashlib, uuid, struct, repr as reprlib, time
 from collections import namedtuple
 from io import BytesIO, DEFAULT_BUFFER_SIZE
 from itertools import chain, repeat, izip_longest
@@ -22,7 +22,8 @@ from calibre.srv.http_request import HTTPRequest, read_headers
 from calibre.srv.sendfile import file_metadata, sendfile_to_socket_async, CannotSendfile, SendfileInterrupted
 from calibre.srv.utils import (
     MultiDict, http_date, HTTP1, HTTP11, socket_errors_socket_closed,
-    sort_q_values, get_translator_for_lang, Cookie, ReadOnlyFileBuffer)
+    sort_q_values, get_translator_for_lang, Cookie)
+from calibre.utils.speedups import ReadOnlyFileBuffer
 from calibre.utils.monotonic import monotonic
 
 Range = namedtuple('Range', 'start stop size')
@@ -138,16 +139,14 @@ def get_ranges(headervalue, content_length):  # {{{
 # }}}
 
 # gzip transfer encoding  {{{
-def gzip_prefix(mtime=None):
+def gzip_prefix():
     # See http://www.gzip.org/zlib/rfc-gzip.html
-    if mtime is None:
-        mtime = time.time()
     return b''.join((
         b'\x1f\x8b',       # ID1 and ID2: gzip marker
         b'\x08',           # CM: compression method
         b'\x00',           # FLG: none set
-        # MTIME: 4 bytes
-        struct.pack(b"<L", int(mtime) & 0xFFFFFFFF),
+        # MTIME: 4 bytes, set to zero so as not to leak timezone information
+        b'\0\0\0\0',
         b'\x02',           # XFL: max compression, slowest algo
         b'\xff',           # OS: unknown
     ))
@@ -168,7 +167,7 @@ def compress_readable_output(src_file, compress_level=6):
         data = zobj.compress(data)
         if not prefix_written:
             prefix_written = True
-            data = gzip_prefix(time.time()) + data
+            data = gzip_prefix() + data
         yield data
     yield zobj.flush() + struct.pack(b"<L", crc) + struct.pack(b"<L", size)
 # }}}
@@ -230,6 +229,9 @@ class RequestData(object):  # {{{
         tuple(map(lambda x:etag.update(string(x)), etag_parts))
         return ETaggedFile(output, etag.hexdigest())
 
+    def filesystem_file_with_constant_etag(self, output, etag_as_hexencoded_string):
+        return ETaggedFile(output, etag_as_hexencoded_string)
+
     def etagged_dynamic_response(self, etag, func, content_type='text/html; charset=UTF-8'):
         ' A response that is generated only if the etag does not match '
         ct = self.outheaders.get('Content-Type')
@@ -397,7 +399,9 @@ class HTTPConnection(HTTPRequest):
         buf = [(x + '\r\n').encode('ascii') for x in buf]
         if self.method != 'HEAD':
             buf.append(msg)
-        self.response_ready(ReadOnlyFileBuffer(b''.join(buf)))
+        response_data = b''.join(buf)
+        self.log_access(status_code=status_code, response_size=len(response_data))
+        self.response_ready(ReadOnlyFileBuffer(response_data))
 
     def prepare_response(self, inheaders, request_body_file):
         if self.method == 'TRACE':
@@ -422,7 +426,9 @@ class HTTPConnection(HTTPRequest):
             "Date: " + http_date(),
             "Content-Range: bytes */%d" % content_length,
         ]
-        self.response_ready(header_list_to_file(buf))
+        response_data = header_list_to_file(buf)
+        self.log_access(status_code=httplib.REQUESTED_RANGE_NOT_SATISFIABLE, response_size=response_data.sz)
+        self.response_ready(response_data)
 
     def send_not_modified(self, etag=None):
         buf = [
@@ -432,7 +438,9 @@ class HTTPConnection(HTTPRequest):
         ]
         if etag is not None:
             buf.append('ETag: ' + etag)
-        self.response_ready(header_list_to_file(buf))
+        response_data = header_list_to_file(buf)
+        self.log_access(status_code=httplib.NOT_MODIFIED, response_size=response_data.sz)
+        self.response_ready(response_data)
 
     def report_busy(self):
         self.simple_response(httplib.SERVICE_UNAVAILABLE)
@@ -484,7 +492,25 @@ class HTTPConnection(HTTPRequest):
                 x = x.decode('ascii')
             buf.append(x)
         buf.append('')
-        self.response_ready(ReadOnlyFileBuffer(b''.join((x + '\r\n').encode('ascii') for x in buf)), output=output)
+        response_data = ReadOnlyFileBuffer(b''.join((x + '\r\n').encode('ascii') for x in buf))
+        if self.access_log is not None:
+            sz = outheaders.get('Content-Length')
+            if sz is not None:
+                sz = int(sz) + response_data.sz
+            self.log_access(status_code=data.status_code, response_size=sz, username=data.username)
+        self.response_ready(response_data, output=output)
+
+    def log_access(self, status_code, response_size=None, username=None):
+        if self.access_log is None:
+            return
+        if not self.opts.log_not_found and status_code == httplib.NOT_FOUND:
+            return
+        line = '%s port-%s %s %s "%s" %s %s' % (
+            self.remote_addr, self.remote_port, username or '-',
+            time.strftime('%d/%b/%Y:%H:%M:%S %z'),
+            force_unicode(self.request_line or '', 'utf-8'),
+            status_code, ('-' if response_size is None else response_size))
+        self.access_log(line)
 
     def response_ready(self, header_file, output=None):
         self.response_started = True
@@ -614,7 +640,7 @@ class HTTPConnection(HTTPRequest):
             return self.send_range_not_satisfiable(output.content_length)
 
         for header in ('Accept-Ranges', 'Content-Encoding', 'Transfer-Encoding', 'ETag', 'Content-Length'):
-            outheaders.pop('header', all=True)
+            outheaders.pop(header, all=True)
 
         matched = '*' in none_match or (output.etag and output.etag in none_match)
         if matched:
