@@ -16,6 +16,7 @@ from calibre.ptempfile import TemporaryDirectory
 from calibre.srv.errors import JobQueueFull
 from calibre.srv.pool import ThreadPool, PluginPool
 from calibre.srv.opts import Options
+from calibre.srv.jobs import JobsManager
 from calibre.srv.utils import (
     socket_errors_socket_closed, socket_errors_nonblocking, HandleInterrupt,
     socket_errors_eintr, start_cork, stop_cork, DESIRED_SEND_BUFFER_SIZE,
@@ -117,8 +118,8 @@ class ReadBuffer(object):  # {{{
 
 class Connection(object):  # {{{
 
-    def __init__(self, socket, opts, ssl_context, tdir, addr, pool, log, wakeup):
-        self.opts, self.pool, self.log, self.wakeup = opts, pool, log, wakeup
+    def __init__(self, socket, opts, ssl_context, tdir, addr, pool, log, access_log, wakeup):
+        self.opts, self.pool, self.log, self.wakeup, self.access_log = opts, pool, log, wakeup, access_log
         try:
             self.remote_addr = addr[0]
             self.remote_port = addr[1]
@@ -304,12 +305,17 @@ class ServerLoop(object):
         plugins=(),
         # A calibre logging object. If None, a default log that logs to
         # stdout is used
-        log=None
+        log=None,
+        # A calibre logging object for access logging, by default no access
+        # logging is performed
+        access_log=None
     ):
         self.ready = False
         self.handler = handler
         self.opts = opts or Options()
         self.log = log or ThreadSafeLog(level=ThreadSafeLog.DEBUG)
+        self.jobs_manager = JobsManager(self.opts, self.log)
+        self.access_log = access_log
 
         ba = (self.opts.listen_on, int(self.opts.port))
         if not ba[0]:
@@ -468,7 +474,7 @@ class ServerLoop(object):
                 (readable if conn.read_buffer.has_data else read_needed).append(s)
 
         for s, conn in remove:
-            self.log.debug('Closing connection because of extended inactivity')
+            self.log('Closing connection because of extended inactivity: %s' % conn.state_description)
             self.close(s, conn)
 
         if readable:
@@ -505,7 +511,7 @@ class ServerLoop(object):
                 if not conn.ready:
                     self.close(s, conn)
             except JobQueueFull:
-                self.log.exception('Server busy handling request: ' % conn.state_description)
+                self.log.exception('Server busy handling request: %s' % conn.state_description)
                 if conn.ready:
                     if conn.response_started:
                         self.close(s, conn)
@@ -558,7 +564,8 @@ class ServerLoop(object):
                 if sock is not None:
                     s = sock.fileno()
                     if s > -1:
-                        self.connection_map[s] = conn = self.handler(sock, self.opts, self.ssl_context, self.tdir, addr, self.pool, self.log, self.wakeup)
+                        self.connection_map[s] = conn = self.handler(
+                            sock, self.opts, self.ssl_context, self.tdir, addr, self.pool, self.log, self.access_log, self.wakeup)
                         if self.ssl_context is not None:
                             yield s, conn, RDWR
             elif s == control:
@@ -602,6 +609,7 @@ class ServerLoop(object):
         self.wakeup()
 
     def shutdown(self):
+        self.jobs_manager.shutdown()
         try:
             if getattr(self, 'socket', None):
                 self.socket.close()
@@ -615,6 +623,7 @@ class ServerLoop(object):
             pool.stop(wait_till)
             if pool.workers:
                 self.log.warn('Failed to shutdown %d workers in %s cleanly' % (len(pool.workers), pool.__class__.__name__))
+        self.jobs_manager.wait_for_shutdown(wait_till)
 
 class EchoLine(Connection):  # {{{
 
