@@ -14,14 +14,17 @@ from urllib import quote
 
 from calibre.constants import config_dir
 from calibre.db.categories import Tag
+from calibre.ebooks.metadata.sources.identify import urls_from_identifiers
 from calibre.utils.date import isoformat, UNDEFINED_DATE, local_tz
-from calibre.utils.config import tweaks, JSONConfig
+from calibre.utils.config import tweaks
 from calibre.utils.formatter import EvalFormatter
 from calibre.utils.file_type_icons import EXT_MAP
 from calibre.utils.icu import collation_order
+from calibre.utils.localization import calibre_langcode_to_name
+from calibre.library.comments import comments_to_html
 from calibre.library.field_metadata import category_icon_map
 
-IGNORED_FIELDS = frozenset('cover ondevice path marked id au_map'.split())
+IGNORED_FIELDS = frozenset('cover ondevice path marked au_map size'.split())
 
 def encode_datetime(dateval):
     if dateval is None:
@@ -45,6 +48,10 @@ def add_field(field, db, book_id, ans, field_metadata):
                 val = encode_datetime(val)
                 if val is None:
                     return
+            elif datatype == 'comments' or field == 'comments':
+                val = comments_to_html(val)
+            elif datatype == 'composite' and field_metadata['display'].get('contains_html'):
+                val = comments_to_html(val)
             ans[field] = val
 
 def book_as_json(db, book_id):
@@ -57,6 +64,12 @@ def book_as_json(db, book_id):
         for field in fm.all_field_keys():
             if field not in IGNORED_FIELDS:
                 add_field(field, db, book_id, ans, fm[field])
+        ids = ans.get('identifiers')
+        if ids:
+            ans['urls_from_identifiers'] = urls_from_identifiers(ids)
+        langs = ans.get('languages')
+        if langs:
+            ans['lang_names'] = {l:calibre_langcode_to_name(l) for l in langs}
     return ans
 
 _include_fields = frozenset(Tag.__slots__) - frozenset({
@@ -65,7 +78,7 @@ _include_fields = frozenset(Tag.__slots__) - frozenset({
 
 def category_as_json(items, category, display_name, count, tooltip=None, parent=None,
         is_editable=True, is_gst=False, is_hierarchical=False, is_searchable=True,
-        is_user_category=False):
+        is_user_category=False, is_first_letter=False):
     ans = {'category': category, 'name': display_name, 'is_category':True, 'count':count}
     if tooltip:
         ans['tooltip'] = tooltip
@@ -81,6 +94,8 @@ def category_as_json(items, category, display_name, count, tooltip=None, parent=
         ans['is_searchable'] = True
     if is_user_category:
         ans['is_user_category'] = True
+    if is_first_letter:
+        ans['is_first_letter'] = True
     item_id = 'c' + str(len(items))
     items[item_id] = ans
     return item_id
@@ -93,11 +108,13 @@ def category_item_as_json(x, clear_rating=False):
             if k == 'original_categories':
                 val = tuple(val)
             ans[k] = val.copy() if isinstance(val, set) else val
+    s = ans.get('sort')
     if x.use_sort_as_name:
-        ans['name'] = ans['sort']
+        ans['name'] = s
     if x.original_name != ans['name']:
         ans['original_name'] = x.original_name
-    ans.pop('sort', None)
+    if x.use_sort_as_name or not s or s == ans['name']:
+        ans.pop('sort', None)
     if clear_rating:
         del ans['avg_rating']
     return ans
@@ -137,8 +154,9 @@ def icon_map():
     global _icon_map
     with _icon_map_lock:
         if _icon_map is None:
+            from calibre.gui2 import gprefs
             _icon_map = category_icon_map.copy()
-            custom_icons = JSONConfig('gui').get('tags_browser_category_icons', {})
+            custom_icons = gprefs.get('tags_browser_category_icons', {})
             for k, v in custom_icons.iteritems():
                 if os.access(os.path.join(config_dir, 'tb_icons', v), os.R_OK):
                     _icon_map[k] = '_' + quote(v)
@@ -153,7 +171,7 @@ def categories_settings(query, db):
     if partition_method not in {'first letter', 'disable', 'partition'}:
         partition_method = 'first letter'
     try:
-        collapse_at = max(0, int(query.get('collapse_at', 25)))
+        collapse_at = max(0, int(float(query.get('collapse_at', 25))))
     except Exception:
         collapse_at = 25
     sort_by = query.get('sort_tags_by', 'name')
@@ -300,7 +318,7 @@ def collapse_first_letter(collapse_nodes, items, category_node, cl_list, idx, is
         node_id = category_as_json(
             items, items[category_node['id']]['category'], collapse_letter, 0,
             parent=category_node['id'], is_editable=False, is_gst=is_gst,
-            is_hierarchical=category_is_hierarchical)
+            is_hierarchical=category_is_hierarchical, is_first_letter=True)
         node_parent = {'id':node_id, 'children':[]}
         category_node['children'].append(node_parent)
         collapse_nodes.append(node_parent)
