@@ -18,7 +18,7 @@ default_methods = frozenset(('HEAD', 'GET'))
 
 def json(ctx, rd, endpoint, output):
     rd.outheaders.set('Content-Type', 'application/json; charset=UTF-8', replace_all=True)
-    if isinstance(output, bytes):
+    if isinstance(output, bytes) or hasattr(output, 'fileno'):
         ans = output  # Assume output is already UTF-8 encoded json
     else:
         ans = jsonlib.dumps(output, ensure_ascii=False)
@@ -135,7 +135,7 @@ class Route(object):
         if argspec.args[2:len(self.names)+2] != self.names:
             raise route_error('Function\'s argument names do not match the variable names in the route')
         if not frozenset(self.type_checkers).issubset(frozenset(self.names)):
-            raise route_error('There exist type checkers that do not correspond to route variables')
+            raise route_error('There exist type checkers that do not correspond to route variables: %r' % (set(self.type_checkers) - set(self.names)))
         self.min_size = found_optional_part if found_optional_part is not False else len(matchers)
         self.max_size = sys.maxsize if self.soak_up_extra else len(matchers)
 
