@@ -57,15 +57,19 @@ def daemonize():  # {{{
 class Server(object):
 
     def __init__(self, libraries, opts):
-        log = None
+        log = access_log = None
+        log_size = opts.max_log_size * 1024 * 1024
         if opts.log:
-            log = RotatingLog(opts.log, max_size=opts.max_log_size)
+            log = RotatingLog(opts.log, max_size=log_size)
+        if opts.access_log:
+            access_log = RotatingLog(opts.access_log, max_size=log_size)
         self.handler = Handler(libraries, opts)
         plugins = []
         if opts.use_bonjour:
             plugins.append(BonJour())
-        self.loop = ServerLoop(create_http_handler(self.handler.dispatch), opts=opts, log=log, plugins=plugins)
+        self.loop = ServerLoop(create_http_handler(self.handler.dispatch), opts=opts, log=log, access_log=access_log, plugins=plugins)
         self.handler.set_log(self.loop.log)
+        self.handler.set_jobs_manager(self.loop.jobs_manager)
         self.serve_forever = self.loop.serve_forever
         self.stop = self.loop.stop
         _df = os.environ.get('CALIBRE_DEVELOP_FROM', None)
@@ -181,7 +185,12 @@ program will be used.
     ))
     parser.add_option(
         '--log', default=None,
-        help=_('Path to log file for server log'))
+        help=_('Path to log file for server log. This log contains server information and errors, not access logs. By default it is written to stdout.'))
+    parser.add_option(
+        '--access-log', default=None,
+        help=_('Path to the access log file. This log contains information'
+               ' about clients connecting to the server and making requests. By'
+               ' default no access logging is done.'))
     parser.add_option('--daemonize', default=False, action='store_true',
         help=_('Run process in background as a daemon. No effect on Windows.'))
     parser.add_option('--pidfile', default=None,
@@ -222,7 +231,7 @@ def main(args=sys.argv):
         from calibre.srv.auto_reload import auto_reload, NoAutoReload
         try:
             from calibre.utils.logging import default_log
-            return auto_reload(default_log)
+            return auto_reload(default_log, listen_on=opts.listen_on)
         except NoAutoReload as e:
             raise SystemExit(e.message)
     opts.auto_reload_port=int(os.environ.get('CALIBRE_AUTORELOAD_PORT', 0))
@@ -237,4 +246,7 @@ def main(args=sys.argv):
     signal.signal(signal.SIGTERM, lambda s,f: server.stop())
     if not opts.daemonize and not iswindows:
         signal.signal(signal.SIGHUP, lambda s,f: server.stop())
+    # Needed for dynamic cover generation, which uses Qt for drawing
+    from calibre.gui2 import ensure_app, load_builtin_fonts
+    ensure_app(), load_builtin_fonts()
     server.serve_forever()
