@@ -19,6 +19,7 @@ from binascii import hexlify, unhexlify
 
 from calibre import prints
 from calibre.constants import iswindows
+from calibre.srv.errors import HTTPNotFound
 from calibre.utils.config_base import tweaks
 from calibre.utils.localization import get_translator
 from calibre.utils.socket_inheritance import set_socket_inherit
@@ -346,7 +347,7 @@ class RotatingStream(object):
                 raise
 
     def rollover(self):
-        if self.max_size is None or self.current_pos <= self.max_size:
+        if not self.max_size or self.current_pos <= self.max_size or self.filename in ('/dev/stdout', '/dev/stderr'):
             return
         self.stream.close()
         for i in xrange(self.history - 1, 0, -1):
@@ -433,39 +434,47 @@ class Accumulator(object):  # {{{
         return ans
 # }}}
 
-class ReadOnlyFileBuffer(object):
+def get_db(ctx, rd, library_id):
+    db = ctx.get_library(rd, library_id)
+    if db is None:
+        raise HTTPNotFound('Library %r not found' % library_id)
+    return db
 
-    ''' A zero copy implementation of a file like object. Uses memoryviews for efficiency. '''
+def get_library_data(ctx, rd):
+    library_id = rd.query.get('library_id')
+    library_map, default_library = ctx.library_info(rd)
+    if library_id not in library_map:
+        library_id = default_library
+    db = get_db(ctx, rd, library_id)
+    return db, library_id, library_map, default_library
 
-    def __init__(self, raw):
-        self.sz, self.mv = len(raw), (raw if isinstance(raw, memoryview) else memoryview(raw))
-        self.pos = 0
+class Offsets(object):
+    'Calculate offsets for a paginated view'
 
-    def tell(self):
-        return self.pos
+    def __init__(self, offset, delta, total):
+        if offset < 0:
+            offset = 0
+        if offset >= total:
+            raise HTTPNotFound('Invalid offset: %r'%offset)
+        last_allowed_index = total - 1
+        last_current_index = offset + delta - 1
+        self.slice_upper_bound = offset+delta
+        self.offset = offset
+        self.next_offset = last_current_index + 1
+        if self.next_offset > last_allowed_index:
+            self.next_offset = -1
+        self.previous_offset = self.offset - delta
+        if self.previous_offset < 0:
+            self.previous_offset = 0
+        self.last_offset = last_allowed_index - delta
+        if self.last_offset < 0:
+            self.last_offset = 0
 
-    def read(self, n=None):
-        if n is None:
-            ans = self.mv[self.pos:]
-            self.pos = self.sz
-            return ans
-        ans = self.mv[self.pos:self.pos+n]
-        self.pos = min(self.pos + n, self.sz)
-        return ans
-
-    def seek(self, pos, whence=os.SEEK_SET):
-        if whence == os.SEEK_SET:
-            self.pos = pos
-        elif whence == os.SEEK_END:
-            self.pos = self.sz + pos
-        else:
-            self.pos += pos
-        self.pos = max(0, min(self.pos, self.sz))
-        return self.pos
-
-    def getvalue(self):
-        return self.mv
-
-    def close(self):
-        pass
+_use_roman = None
 
+def get_use_roman():
+    global _use_roman
+    if _use_roman is None:
+        from calibre.gui2 import config
+        _use_roman = config['use_roman_numerals_for_series_number']
+    return _use_roman
