@@ -12,7 +12,7 @@ __docformat__ = 'restructuredtext en'
 Test a binary calibre build to ensure that all needed binary images/libraries have loaded.
 '''
 
-import cStringIO, os, ctypes, sys
+import os, ctypes, sys
 from calibre.constants import plugins, iswindows, islinux, isosx
 
 def fprint(*args, **kwargs):
@@ -101,17 +101,12 @@ def test_fsevents():
     fprint('macfsevents OK!')
 
 def test_winutil():
-    from calibre.devices.scanner import win_pnp_drives
     from calibre.constants import plugins
     winutil = plugins['winutil'][0]
-    try:
-        matches = win_pnp_drives.scanner()
-    except winutil.DriveError:
-        fprint('No removable drives found, skipping win_pnp_drives test!')
-        return
-    if len(matches) < 1:
-        raise RuntimeError('win_pnp_drives returned no drives')
-    fprint('win_pnp_drives OK!')
+    for x in winutil.argv():
+        if not isinstance(x, unicode):
+            raise ValueError('argv() not returning unicode string')
+    fprint('winutil OK!')
 
 def test_sqlite():
     import sqlite3
@@ -127,7 +122,22 @@ def test_apsw():
     conn.close()
     fprint('apsw OK!')
 
+def test_image_formats():
+    # Must be run before QApplication is constructed
+    # Test that the image formats are available without a QApplication being
+    # constructed
+    from calibre.utils.img import image_from_data, image_to_data, test
+    data = I('blank.png', allow_user_override=False, data=True)
+    img = image_from_data(data)
+    image_from_data(P('catalog/mastheadImage.gif', allow_user_override=False, data=True))
+    for fmt in 'png bmp jpeg'.split():
+        d = image_to_data(img, fmt=fmt)
+        image_from_data(d)
+    # Run the imaging tests
+    test()
+
 def test_qt():
+    test_image_formats()
     from calibre.gui2 import Application
     from PyQt5.Qt import (QImageReader, QNetworkAccessManager, QFontDatabase)
     from PyQt5.QtWebKitWidgets import QWebView
@@ -136,7 +146,7 @@ def test_qt():
     if len(QFontDatabase().families()) < 5:
         raise RuntimeError('The QPA headless plugin is not able to locate enough system fonts via fontconfig')
     fmts = set(map(unicode, QImageReader.supportedImageFormats()))
-    testf = set(['jpg', 'png', 'mng', 'svg', 'ico', 'gif'])
+    testf = set(['jpg', 'png', 'svg', 'ico', 'gif'])
     if testf.intersection(fmts) != testf:
         raise RuntimeError(
             "Qt doesn't seem to be able to load its image plugins")
@@ -150,12 +160,6 @@ def test_qt():
     fprint('Qt OK!')
 
 def test_imaging():
-    from calibre.ebooks import calibre_cover
-    data = calibre_cover('test', 'ok')
-    if len(data) > 1000:
-        fprint('ImageMagick OK!')
-    else:
-        raise RuntimeError('ImageMagick choked!')
     from PIL import Image
     try:
         import _imaging, _imagingmath, _imagingft
@@ -163,21 +167,21 @@ def test_imaging():
     except ImportError:
         from PIL import _imaging, _imagingmath, _imagingft
     _imaging, _imagingmath, _imagingft
-    i = Image.open(cStringIO.StringIO(data))
+    i = Image.open(I('lt.png', allow_user_override=False))
     if i.size < (20, 20):
         raise RuntimeError('PIL choked!')
     fprint('PIL OK!')
 
+def test_file_dialog_helper():
+    from calibre.gui2.win_file_dialogs import test
+    test()
+    print('File dialog helper OK!')
+
 def test_unrar():
     from calibre.utils.unrar import test_basic
     test_basic()
     fprint('Unrar OK!')
 
-def test_ssl():
-    import ssl
-    ssl
-    fprint('SSL OK!')
-
 def test_icu():
     fprint('Testing ICU')
     from calibre.utils.icu_test import test_build
@@ -200,14 +204,6 @@ def test_wpd():
         wpd.uninit()
     fprint('WPD OK!')
 
-def test_magick():
-    from calibre.utils.magick import create_canvas
-    i = create_canvas(100, 100)
-    from calibre.gui2.tweak_book.editor.canvas import qimage_to_magick, magick_to_qimage
-    img = magick_to_qimage(i)
-    i = qimage_to_magick(img)
-    fprint('magick OK!')
-
 def test_tokenizer():
     fprint('Testing tinycss tokenizer')
     from tinycss.tokenizer import c_tokenize_flat
@@ -269,6 +265,15 @@ def test_image_compression():
     test()
     fprint('Image compression OK!')
 
+def test_openssl():
+    import ssl
+    ssl.PROTOCOL_TLSv1_2
+    if isosx:
+        cafile = ssl.get_default_verify_paths().cafile
+        if not cafile or not cafile.endswith('/mozilla-ca-certs.pem') or not os.access(cafile, os.R_OK):
+            raise ValueError('Mozilla CA certs not loaded')
+    fprint('SSL OK!')
+
 def test():
     if iswindows:
         test_dlls()
@@ -279,7 +284,7 @@ def test():
     test_dukpy()
     test_spell()
     test_lxml()
-    test_ssl()
+    test_openssl()
     test_sqlite()
     test_apsw()
     test_imaging()
@@ -289,7 +294,6 @@ def test():
     test_qt()
     test_html5lib()
     test_regex()
-    test_magick()
     test_tokenizer()
     test_netifaces()
     test_psutil()
@@ -300,6 +304,7 @@ def test():
     if iswindows:
         test_wpd()
         test_winutil()
+        test_file_dialog_helper()
     else:
         test_terminal()
     if isosx:
