@@ -6,7 +6,7 @@ __copyright__ = '2010, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
 import copy, httplib, ssl
-from cookielib import CookieJar
+from cookielib import CookieJar, Cookie
 
 from mechanize import Browser as B, HTTPSHandler
 
@@ -60,9 +60,14 @@ class Browser(B):
         B.set_cookiejar(self, *args, **kwargs)
         self._clone_actions['set_cookiejar'] = ('set_cookiejar', args, kwargs)
 
-    def copy_cookies_from_jsbrowser(self, jsbrowser):
-        for cookie in jsbrowser.cookies:
-            self.cookiejar.set_cookie(cookie)
+    def set_cookie(self, name, value, domain, path='/'):
+        self.cookiejar.set_cookie(Cookie(
+            None, name, value,
+            None, False,
+            domain, True, False,
+            path, True,
+            False, None, False, None, None, None
+        ))
 
     @property
     def cookiejar(self):
@@ -83,9 +88,9 @@ class Browser(B):
         self._clone_actions['set_handle_gzip'] = ('set_handle_gzip',
                 (handle,), {})
 
-    def set_debug_redirect(self, *args, **kwargs):
-        B.set_debug_redirect(self, *args, **kwargs)
-        self._clone_actions['set_debug_redirect'] = ('set_debug_redirect',
+    def set_debug_redirects(self, *args, **kwargs):
+        B.set_debug_redirects(self, *args, **kwargs)
+        self._clone_actions['set_debug_redirects'] = ('set_debug_redirects',
                 args, kwargs)
 
     def set_debug_responses(self, *args, **kwargs):
