@@ -28,8 +28,7 @@ class FormatterFunctions(object):
     error_function_body = ('def evaluate(self, formatter, kwargs, mi, locals):\n'
                        '\treturn "' +
                             _('Duplicate user function name {0}. '
-                              'Change the name or ensure that the functions are identical')
-                                       + '"')
+                              'Change the name or ensure that the functions are identical') + '"')
 
     def __init__(self):
         self._builtins = {}
@@ -417,7 +416,7 @@ class BuiltinTest(BuiltinFormatterFunction):
     arg_count = 3
     category = 'If-then-else'
     __doc__ = doc = _('test(val, text if not empty, text if empty) -- return `text if not '
-            'empty` if the field is not empty, otherwise return `text if empty`')
+            'empty` if val is not empty, otherwise return `text if empty`')
 
     def evaluate(self, formatter, kwargs, mi, locals, val, value_if_set, value_not_set):
         if val:
@@ -430,7 +429,7 @@ class BuiltinContains(BuiltinFormatterFunction):
     arg_count = 4
     category = 'If-then-else'
     __doc__ = doc = _('contains(val, pattern, text if match, text if not match) -- checks '
-            'if field contains matches for the regular expression `pattern`. '
+            'if val contains matches for the regular expression `pattern`. '
             'Returns `text if match` if matches are found, otherwise it returns '
             '`text if no match`')
 
@@ -446,9 +445,9 @@ class BuiltinSwitch(BuiltinFormatterFunction):
     arg_count = -1
     category = 'Iterating over values'
     __doc__ = doc = _('switch(val, pattern, value, pattern, value, ..., else_value) -- '
-            'for each `pattern, value` pair, checks if the field matches '
+            'for each `pattern, value` pair, checks if `val` matches '
             'the regular expression `pattern` and if so, returns that '
-            '`value`. If no pattern matches, then else_value is returned. '
+            '`value`. If no pattern matches, then `else_value` is returned. '
             'You can have as many `pattern, value` pairs as you want')
 
     def evaluate(self, formatter, kwargs, mi, locals, val, *args):
@@ -565,7 +564,7 @@ class BuiltinRe(BuiltinFormatterFunction):
     name = 're'
     arg_count = 3
     category = 'String manipulation'
-    __doc__ = doc = _('re(val, pattern, replacement) -- return the field after applying '
+    __doc__ = doc = _('re(val, pattern, replacement) -- return val after applying '
             'the regular expression. All instances of `pattern` are replaced '
             'with `replacement`. As in all of calibre, these are '
             'python-compatible regular expressions')
@@ -637,8 +636,8 @@ class BuiltinShorten(BuiltinFormatterFunction):
     arg_count = 4
     category = 'String manipulation'
     __doc__ = doc = _('shorten(val, left chars, middle text, right chars) -- Return a '
-            'shortened version of the field, consisting of `left chars` '
-            'characters from the beginning of the field, followed by '
+            'shortened version of val, consisting of `left chars` '
+            'characters from the beginning of val, followed by '
             '`middle text`, followed by `right chars` characters from '
             'the end of the string. `Left chars` and `right chars` must be '
             'integers. For example, assume the title of the book is '
@@ -741,10 +740,10 @@ class BuiltinFormatsModtimes(BuiltinFormatterFunction):
     arg_count = 1
     category = 'Get values from metadata'
     __doc__ = doc = _('formats_modtimes(date_format) -- return a comma-separated '
-                  'list of colon_separated items representing modification times '
+                  'list of colon-separated items representing modification times '
                   'for the formats of a book. The date_format parameter '
                   'specifies how the date is to be formatted. See the '
-                  'date_format function for details. You can use the select '
+                  'format_date function for details. You can use the select '
                   'function to get the mod time for a specific '
                   'format. Note that format names are always uppercase, '
                   'as in EPUB.'
@@ -761,7 +760,7 @@ class BuiltinFormatsSizes(BuiltinFormatterFunction):
     arg_count = 0
     category = 'Get values from metadata'
     __doc__ = doc = _('formats_sizes() -- return a comma-separated list of '
-                      'colon_separated items representing sizes in bytes '
+                      'colon-separated items representing sizes in bytes '
                       'of the formats of a book. You can use the select '
                       'function to get the size for a specific '
                       'format. Note that format names are always uppercase, '
@@ -777,7 +776,7 @@ class BuiltinFormatsPaths(BuiltinFormatterFunction):
     arg_count = 0
     category = 'Get values from metadata'
     __doc__ = doc = _('formats_paths() -- return a comma-separated list of '
-                      'colon_separated items representing full path to '
+                      'colon-separated items representing full path to '
                       'the formats of a book. You can use the select '
                       'function to get the path for a specific '
                       'format. Note that format names are always uppercase, '
@@ -952,7 +951,7 @@ class BuiltinUppercase(BuiltinFormatterFunction):
     name = 'uppercase'
     arg_count = 1
     category = 'String case changes'
-    __doc__ = doc = _('uppercase(val) -- return value of the field in upper case')
+    __doc__ = doc = _('uppercase(val) -- return val in upper case')
 
     def evaluate(self, formatter, kwargs, mi, locals, val):
         return val.upper()
@@ -961,7 +960,7 @@ class BuiltinLowercase(BuiltinFormatterFunction):
     name = 'lowercase'
     arg_count = 1
     category = 'String case changes'
-    __doc__ = doc = _('lowercase(val) -- return value of the field in lower case')
+    __doc__ = doc = _('lowercase(val) -- return val in lower case')
 
     def evaluate(self, formatter, kwargs, mi, locals, val):
         return val.lower()
@@ -970,7 +969,7 @@ class BuiltinTitlecase(BuiltinFormatterFunction):
     name = 'titlecase'
     arg_count = 1
     category = 'String case changes'
-    __doc__ = doc = _('titlecase(val) -- return value of the field in title case')
+    __doc__ = doc = _('titlecase(val) -- return val in title case')
 
     def evaluate(self, formatter, kwargs, mi, locals, val):
         return titlecase(val)
@@ -979,7 +978,7 @@ class BuiltinCapitalize(BuiltinFormatterFunction):
     name = 'capitalize'
     arg_count = 1
     category = 'String case changes'
-    __doc__ = doc = _('capitalize(val) -- return value of the field capitalized')
+    __doc__ = doc = _('capitalize(val) -- return val capitalized')
 
     def evaluate(self, formatter, kwargs, mi, locals, val):
         return capitalize(val)
@@ -1072,7 +1071,7 @@ class BuiltinAnd(BuiltinFormatterFunction):
     __doc__ = doc = _('and(value, value, ...) -- '
             'returns the string "1" if all values are not empty, otherwise '
             'returns the empty string. This function works well with test or '
-            'first_non_empty. You can have as many values as you want.')
+            'first_non_empty. You can have as many values as you want. ')
 
     def evaluate(self, formatter, kwargs, mi, locals, *args):
         i = 0
@@ -1106,7 +1105,7 @@ class BuiltinNot(BuiltinFormatterFunction):
     __doc__ = doc = _('not(value) -- '
             'returns the string "1" if the value is empty, otherwise '
             'returns the empty string. This function works well with test or '
-            'first_non_empty. You can have as many values as you want.')
+            'first_non_empty.')
 
     def evaluate(self, formatter, kwargs, mi, locals, val):
         return '' if val else '1'
@@ -1117,7 +1116,7 @@ class BuiltinListUnion(BuiltinFormatterFunction):
     category = 'List manipulation'
     __doc__ = doc = _('list_union(list1, list2, separator) -- '
             'return a list made by merging the items in list1 and list2, '
-            'removing duplicate items using a case-insensitive compare. If '
+            'removing duplicate items using a case-insensitive comparison. If '
             'items differ in case, the one in list1 is used. '
             'The items in list1 and list2 are separated by separator, as are '
             'the items in the returned list.')
@@ -1141,7 +1140,7 @@ class BuiltinListDifference(BuiltinFormatterFunction):
     category = 'List manipulation'
     __doc__ = doc = _('list_difference(list1, list2, separator) -- '
             'return a list made by removing from list1 any item found in list2, '
-            'using a case-insensitive compare. The items in list1 and list2 '
+            'using a case-insensitive comparison. The items in list1 and list2 '
             'are separated by separator, as are the items in the returned list.')
 
     def evaluate(self, formatter, kwargs, mi, locals, list1, list2, separator):
@@ -1162,7 +1161,7 @@ class BuiltinListIntersection(BuiltinFormatterFunction):
     category = 'List manipulation'
     __doc__ = doc = _('list_intersection(list1, list2, separator) -- '
             'return a list made by removing from list1 any item not found in list2, '
-            'using a case-insensitive compare. The items in list1 and list2 '
+            'using a case-insensitive comparison. The items in list1 and list2 '
             'are separated by separator, as are the items in the returned list.')
 
     def evaluate(self, formatter, kwargs, mi, locals, list1, list2, separator):
@@ -1201,7 +1200,7 @@ class BuiltinListEquals(BuiltinFormatterFunction):
             'otherwise return no_val. The items are determined by splitting '
             'each list using the appropriate separator character (sep1 or '
             'sep2). The order of items in the lists is not relevant. '
-            'The compare is case insensitive.')
+            'The comparison is case insensitive.')
 
     def evaluate(self, formatter, kwargs, mi, locals, list1, sep1, list2, sep2, yes_val, no_val):
         s1 = set([icu_lower(l.strip()) for l in list1.split(sep1) if l.strip()])
