@@ -227,8 +227,9 @@ per_language_title_sort_articles = {
         'spa'  : (r'El\s+', r'La\s+', r'Lo\s+', r'Los\s+', r'Las\s+', r'Un\s+',
                   r'Una\s+', r'Unos\s+', r'Unas\s+'),
         # French
-        'fra'  : (r'Le\s+', r'La\s+', r"L'", u'L´', r'Les\s+', r'Un\s+', r'Une\s+',
-                  r'Des\s+', r'De\s+La\s+', r'De\s+', r"D'", u'D´'),
+        'fra'  : (r'Le\s+', r'La\s+', r"L'", u'L´', u'L’', r'Les\s+', r'Un\s+', r'Une\s+',
+                  r'Des\s+', r'De\s+La\s+', r'De\s+', r"D'", u'D´', u'L’'),
+
         # Italian
         'ita': ('Lo\\s+', 'Il\\s+', "L'", 'L\xb4', 'La\\s+', 'Gli\\s+',
                 'I\\s+', 'Le\\s+', 'Uno\\s+', 'Un\\s+', 'Una\\s+', "Un'",
@@ -384,14 +385,6 @@ maximum_resort_levels = 5
 # the fields that are being displayed.
 sort_dates_using_visible_fields = False
 
-#: Specify which font to use when generating a default cover or masthead
-# Absolute path to .ttf font files to use as the fonts for the title, author
-# and footer when generating a default cover or masthead image. Useful if the
-# default font (Liberation Serif) does not contain glyphs for the language of
-# the books in your library.
-generate_cover_title_font = None
-generate_cover_foot_font = None
-
 #: Fuzz value for trimming covers
 # The value used for the fuzz distance when trimming a cover.
 # Colors within this distance are considered equal.
@@ -401,8 +394,8 @@ cover_trim_fuzz_value = 10
 #: Control behavior of the book list
 # You can control the behavior of doubleclicks on the books list.
 # Choices: open_viewer, do_nothing,
-# edit_cell, edit_metadata. Selecting edit_metadata has the side effect of
-# disabling editing a field using a single click.
+# edit_cell, edit_metadata. Selecting anything other than open_viewer has the
+# side effect of disabling editing a field using a single click.
 # Default: open_viewer.
 # Example: doubleclick_on_library_view = 'do_nothing'
 # You can also control whether the book list scrolls horizontal per column or
@@ -441,7 +434,7 @@ metadata_edit_custom_column_order = []
 
 #: The number of seconds to wait before sending emails
 # The number of seconds to wait before sending emails when using a
-# public email server like gmail or hotmail. Default is: 5 minutes
+# public email server like gmx/hotmail/gmail. Default is: 5 minutes
 # Setting it to lower may cause the server's SPAM controls to kick in,
 # making email sending fail. Changes will take effect only after a restart of
 # calibre.
